# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import base64
import unittest
from zlib import compress

from mixbox.vendor import six
from mixbox.vendor.six import u

from cybox.objects.artifact_object import (Artifact, Base64Encoding,
                                           Bz2Compression, Encoding, EncodingFactory, Packaging, RawArtifact,
                                           XOREncryption, ZlibCompression)
from cybox.test import round_trip
from cybox.test.objects import ObjectTestCase


class TestRawArtifact(unittest.TestCase):

    def test_xml_output(self):
        # A RawArtifact stores a Unicode string, even though it typically
        # consists only of valid Base64 characters.
        data = u("0123456789abcdef")
        ra = RawArtifact(data)

        expected_data = data.encode('utf-8')
        self.assertTrue(expected_data in ra.to_xml())


class TestArtifactEncoding(unittest.TestCase):

    def test_cannot_create_artifact_from_unicode_data(self):
        self.assertRaises(ValueError, Artifact, u("abc123"))

    def test_setting_ascii_artifact_data_no_packaging(self):
        a = Artifact()
        a.data = b"abc123"
        self.assertEqual(six.binary_type, type(a.data))
        self.assertEqual(six.text_type, type(a.packed_data))

    def test_cannot_set_nonascii_data_with_no_packaging(self):
        a = Artifact()
        # You can set this data, but if you don't add any packaging, you should
        # get an error when trying to get the packed data, since it can't be
        # encoded as ASCII.
        a.data = b"\x00abc123\xff"
        self.assertEqual(six.binary_type, type(a.data))
        self.assertRaises(ValueError, _get_packed_data, a)

        # With Base64 encoding, we can retrieve this.
        a.packaging = Packaging()
        a.packaging.encoding.append(Base64Encoding())
        self.assertEqual("AGFiYzEyM/8=", a.packed_data)

    def test_setting_ascii_artifact_packed_data_no_packaging(self):
        a = Artifact()
        a.packed_data = u("abc123")
        self.assertEqual(six.binary_type, type(a.data))
        self.assertEqual(six.text_type, type(a.packed_data))

    def test_cannot_set_nonascii_artifact_packed_data(self):
        a = Artifact()
        a.packed_data = u("\x00abc123\xff")
        self.assertEqual(six.text_type, type(a.packed_data))

        # TODO: Should this raise an error sooner, since there's nothing we can
        #  do at this point? There's no reason that the packed_data should
        #  contain non-ascii characters.
        self.assertRaises(UnicodeEncodeError, _get_data, a)


class TestArtifact(ObjectTestCase, unittest.TestCase):
    object_type = "ArtifactObjectType"
    klass = Artifact

    ascii_data = b"ABCDEFGHIJKLMNOPQRSTUVWZYZ0123456879"
    binary_data = b"\xde\xad\xbe\xef Dead Beef"

    # The raw_artifact data in a JSON/dict representation should always be
    # ASCII byte data (typically Base64-encoded, but this is not required).
    _full_dict = {
        'raw_artifact': "Here is a blob of text.",
        'type': Artifact.TYPE_NETWORK,
        'xsi:type': object_type,
    }

    def test_set_data_and_packed_data(self):
        a = Artifact()
        self.assertEqual(a.data, None)
        self.assertEqual(a.packed_data, None)

        a.data = b"Blob"
        self.assertRaises(ValueError, _set_packed_data, a, u("blob"))
        a.data = None

        a.packed_data = u("Blob")
        self.assertRaises(ValueError, _set_data, a, b"blob")
        a.packed_data = None

    def test_round_trip(self):
        # Without any packaging, the only data an Artifact can encode
        # successfully is ASCII data.
        a = Artifact(self.ascii_data, Artifact.TYPE_GENERIC)
        a2 = round_trip(a, Artifact)
        self.assertEqual(a.to_dict(), a2.to_dict())

    def test_non_ascii_round_trip_raises_error(self):
        a = Artifact(self.binary_data, Artifact.TYPE_GENERIC)
        # Since the data is non-ASCII, this should raise an error.
        self.assertRaises(ValueError, round_trip, a, Artifact)

    def test_base64_encoding(self):
        a = Artifact(self.binary_data)
        a.packaging = Packaging()
        a.packaging.encoding.append(Base64Encoding())
        a2 = round_trip(a, Artifact)
        self.assertEqual(self.binary_data, a2.data)

        expected = base64.b64encode(self.binary_data).decode('ascii')
        self.assertEqual(expected, a2.packed_data)

    def test_zlib_base64_encoding(self):
        a = Artifact(self.binary_data)
        a.packaging = Packaging()
        a.packaging.compression.append(ZlibCompression())
        a.packaging.encoding.append(Base64Encoding())
        a2 = round_trip(a, Artifact)
        self.assertEqual(self.binary_data, a2.data)

        expected = base64.b64encode(compress(self.binary_data)).decode('ascii')
        self.assertEqual(expected, a2.packed_data)

    def test_encryption(self):
        a = Artifact(self.binary_data)
        a.packaging = Packaging()
        a.packaging.encryption.append(XOREncryption(0x4a))
        a.packaging.encoding.append(Base64Encoding())
        a2 = round_trip(a, Artifact)

        self.assertEqual(self.binary_data, a2.data)

    def test_compression(self):
        a = Artifact(self.binary_data)
        a.packaging = Packaging()
        a.packaging.compression.append(Bz2Compression())
        a.packaging.encryption.append(XOREncryption(0x4a))
        a.packaging.encoding.append(Base64Encoding())
        a2 = round_trip(a, Artifact)

        self.assertEqual(self.binary_data, a2.data)

    def test_custom_encoding(self):
        @EncodingFactory.register_extension
        class Base32Encoding(Encoding):
            _ENCODING_TYPE = "Base32"

            def __init__(self):
                super(Base32Encoding, self).__init__(algorithm="Base32")

            def pack(self, data):
                return base64.b32encode(data)

            def unpack(self, packed_data):
                return base64.b32decode(packed_data)

        a = Artifact(self.binary_data)
        a.packaging = Packaging()
        a.packaging.compression.append(Bz2Compression())
        a.packaging.encryption.append(XOREncryption(0x4a))
        a.packaging.encoding.append(Base32Encoding())
        a2 = round_trip(a, Artifact)

        self.assertEqual(self.binary_data, a2.data)


class TestArtifactInstance(ObjectTestCase, unittest.TestCase):
    object_type = "ArtifactObjectType"
    klass = Artifact

    _full_dict = {
        "packaging": {
            "is_encrypted": False,
            "is_compressed": False,
            "encoding": [
                {
                    "algorithm": "Base64"
                }
            ]
        },
        "xsi:type": object_type,
        "raw_artifact": "1MOyoQIABAAAAAAAAAAAAP//AAABAAAAsmdKQq6RBwBGAAAARgAAAADAnzJBjADg"
                        "GLEMrQgARQAAOAAAQABAEWVHwKiqCMCoqhSAGwA1ACSF7RAyAQAAAQAAAAAAAAZn"
                        "b29nbGUDY29tAAAQAAGyZ0pCwJMHAGIAAABiAAAAAOAYsQytAMCfMkGMCABFAABU"
                        "y+wAAIARmT7AqKoUwKiqCAA1gBsAQMclEDKBgAABAAEAAAAABmdvb2dsZQNjb20A"
                        "ABAAAcAMABAAAQAAAQ4AEA92PXNwZjEgcHRyID9hbGy2Z0pCFKYHAEYAAABGAAAA"
                        "AMCfMkGMAOAYsQytCABFAAA4AABAAEARZUfAqKoIwKiqFIAbADUAJJ6w928BAAAB"
                        "AAAAAAAABmdvb2dsZQNjb20AAA8AAbdnSkJZFgUAKgEAACoBAAAA4BixDK0AwJ8y"
                        "QYwIAEUAARzMuwAAgBGXp8CoqhTAqKoIADWAGwEI1vP3b4GAAAEABgAAAAYGZ29v"
                        "Z2xlA2NvbQAADwABwAwADwABAAACKAAKACgFc210cDTADMAMAA8AAQAAAigACgAK"
                        "BXNtdHA1wAzADAAPAAEAAAIoAAoACgVzbXRwNsAMwAwADwABAAACKAAKAAoFc210"
                        "cDHADMAMAA8AAQAAAigACgAKBXNtdHAywAzADAAPAAEAAAIoAAoAKAVzbXRwM8AM"
                        "wCoAAQABAAACWAAE2O8lGsBAAAEAAQAAAlgABEDppxnAVgABAAEAAAJYAARCZgkZ"
                        "wGwAAQABAAACWAAE2O85GcCCAAEAAQAAAlgABNjvJRnAmAABAAEAAAJYAATY7zka"
                        "v2dKQo/HBABGAAAARgAAAADAnzJBjADgGLEMrQgARQAAOAAAQABAEWVHwKiqCMCo"
                        "qhSAGwA1ACRMcUmhAQAAAQAAAAAAAAZnb29nbGUDY29tAAAdAAG/Z0pCn+YGAEYA"
                        "AABGAAAAAOAYsQytAMCfMkGMCABFAAA4zM0AAIARmHnAqKoUwKiqCAA1gBsAJMvw"
                        "SaGBgAABAAAAAAAABmdvb2dsZQNjb20AAB0AAcdnSkJp5QQAVQAAAFUAAAAAwJ8y"
                        "QYwA4BixDK0IAEUAAEcAAEAAQBFlOMCoqgjAqKoUgBsANQAzF8KbuwEAAAEAAAAA"
                        "AAADMTA0ATkDMTkyAjY2B2luLWFkZHIEYXJwYQAADAABx2dKQmPnBACBAAAAgQAA"
                        "AADgGLEMrQDAnzJBjAgARQAAc80bAACAEZfwwKiqFMCoqggANYAbAF+CtZu7gYAA"
                        "AQABAAAAAAMxMDQBOQMxOTICNjYHaW4tYWRkcgRhcnBhAAAMAAHADAAMAAEAAVEl"
                        "ACAMNjYtMTkyLTktMTA0A2dlbgl0d3RlbGVjb20DbmV0AA5oSkJ/dwoASgAAAEoA"
                        "AAAAwJ8yQYwA4BixDK0IAEUAADwAAEAAQBFlQ8CoqgjAqKoUgBsANQAor2F1wAEA"
                        "AAEAAAAAAAADd3d3Bm5ldGJzZANvcmcAAAEAAQ5oSkKONgsAWgAAAFoAAAAA4Bix"
                        "DK0AwJ8yQYwIAEUAAEzP+QAAgBGVOcCoqhTAqKoIADWAGwA4oxd1wIGAAAEAAQAA"
                        "AAADd3d3Bm5ldGJzZANvcmcAAAEAAcAMAAEAAQABQO8ABMyYvgwfaEpCfQkHAEoA"
                        "AABKAAAAAMCfMkGMAOAYsQytCABFAAA8b0xAAEAR9fbAqKoIwKiqFIAbADUAKDQy"
                        "8NQBAAABAAAAAAAAA3d3dwZuZXRic2QDb3JnAAAcAAEfaEpC4akKAGYAAABmAAAA"
                        "AOAYsQytAMCfMkGMCABFAABY0FoAAIARlMzAqKoUwKiqCAA1gBsARF8b8NSBgAAB"
                        "AAEAAAAAA3d3dwZuZXRic2QDb3JnAAAcAAHADAAcAAEAAVGAABAgAQT4AAQABwLg"
                        "gf/+UpprW2hKQrD8BwBKAAAASgAAAADAnzJBjADgGLEMrQgARQAAPAAAQABAEWVD"
                        "wKiqCMCoqhSAGwA1ACilzX85AQAAAQAAAAAAAAN3d3cGbmV0YnNkA29yZwAAHAAB"
                        "W2hKQjP+BwBmAAAAZgAAAADgGLEMrQDAnzJBjAgARQAAWNRPAACAEZDXwKiqFMCo"
                        "qggANYAbAETQ8n85gYAAAQABAAAAAAN3d3cGbmV0YnNkA29yZwAAHAABwAwAHAAB"
                        "AAFRRAAQIAEE+AAEAAcC4IH//lKaa2RoSkKSOgsASgAAAEoAAAAAwJ8yQYwA4Bix"
                        "DK0IAEUAADwAAEAAQBFlQ8CoqgjAqKoUgBsANQAojWmNswEAAAEAAAAAAAADd3d3"
                        "Bmdvb2dsZQNjb20AABwAAWRoSkIsewsAXgAAAF4AAAAA4BixDK0AwJ8yQYwIAEUA"
                        "AFDUbQAAgBGQwcCoqhTAqKoIADWAGwA8DcGNs4GAAAEAAQAAAAADd3d3Bmdvb2ds"
                        "ZQNjb20AABwAAcAMAAUAAQAAAnkACAN3d3cBbMAQbmhKQqZWBQBMAAAATAAAAADA"
                        "nzJBjADgGLEMrQgARQAAPgAAQABAEWVBwKiqCMCoqhSAGwA1ACo9CtyiAQAAAQAA"
                        "AAAAAAN3d3cBbAZnb29nbGUDY29tAAAcAAFuaEpCv5cFAEwAAABMAAAAAOAYsQyt"
                        "AMCfMkGMCABFAAA+1TkAAIARkAfAqKoUwKiqCAA1gBsAKryJ3KKBgAABAAAAAAAA"
                        "A3d3dwFsBmdvb2dsZQNjb20AABwAAZdoSkI8HgMASwAAAEsAAAAAwJ8yQYwA4Bix"
                        "DK0IAEUAAD0AAEAAQBFlQsCoqgjAqKoUgBsANQApiGG8HwEAAAEAAAAAAAADd3d3"
                        "B2V4YW1wbGUDY29tAAAcAAGXaEpC86wGAEsAAABLAAAAAOAYsQytAMCfMkGMCABF"
                        "AAA91p8AAIARjqLAqKoUwKiqCAA1gBsAKQfhvB+BgAABAAAAAAAAA3d3dwdleGFt"
                        "cGxlA2NvbQAAHAABomhKQhCDDABPAAAATwAAAADAnzJBjADgGLEMrQgARQAAQQAA"
                        "QABAEWU+wKiqCMCoqhSAGwA1AC1EKCZtAQAAAQAAAAAAAAN3d3cHZXhhbXBsZQdu"
                        "b3RnaW5oAAAcAAGjaEpC0IAAAE8AAABPAAAAAOAYsQytAMCfMkGMCABFAABB1y4A"
                        "AIARjg/AqKoUwKiqCAA1gBsALb+kJm2FgwABAAAAAAAAA3d3dwdleGFtcGxlB25v"
                        "dGdpbmgAABwAAcFoSkIsFQoARwAAAEcAAAAAwJ8yQYwA4BixDK0IAEUAADkAAEAA"
                        "QBFlRsCoqgjAqKoUgBsANQAlQm7+4wEAAAEAAAAAAAADd3d3A2lzYwNvcmcAAP8A"
                        "AcFoSkLIMAsAcwAAAHMAAAAA4BixDK0AwJ8yQYwIAEUAAGXY9AAAgBGMJcCoqhTA"
                        "qKoIADWAGwBRy2T+44GAAAEAAgAAAAADd3d3A2lzYwNvcmcAAP8AAcAMABwAAQAA"
                        "AlgAECABBPgAAAACAAAAAAAAAA3ADAABAAEAAAJYAATMmLhYwWhKQrQ/CwBSAAAA"
                        "UgAAAADAnzJBjADgGLEMrQgARQAARAAAQABAEWU7wKiqCMCoqhSAHAA1ADACNVpT"
                        "AQAAAQAAAAAAAAExATABMAMxMjcHaW4tYWRkcgRhcnBhAAAMAAHBaEpCAEILAGkA"
                        "AABpAAAAAOAYsQytAMCfMkGMCABFAABb2PUAAIARjC7AqKoUwKiqCAA1gBwAR/kw"
                        "WlOFgAABAAEAAAAAATEBMAEwAzEyNwdpbi1hZGRyBGFycGEAAAwAAcAMAAwAAQAA"
                        "DhAACwlsb2NhbGhvc3QAwWhKQkZLCwBDAAAAQwAAAADAnzJBjADgGLEMrQgARQAA"
                        "NQAAQABAEWVKwKiqCMCoqhSAHQA1ACGYvSCKAQAAAQAAAAAAAANpc2MDb3JnAAAC"
                        "AAHBaEpC2ogLAIEAAACBAAAAABKpADIjAGAIReRVCABFAABzh94AAIARapXAqKo4"
                        "2Q0EGAarADUAXznwMm4BAAABAAAAAAAABV9sZGFwBF90Y3AXRGVmYXVsdC1GaXJz"
                        "dC1TaXRlLU5hbWUGX3NpdGVzAmRjBl9tc2Rjcwt1dGVsc3lzdGVtcwVsb2NhbAAA"
                        "IQABwWhKQrWSCwCmAAAApgAAAADgGLEMrQDAnzJBjAgARQAAmNj3AACAEYvvwKiq"
                        "FMCoqggANYAdAIR72CCKgYAAAQAEAAAAAANpc2MDb3JnAAACAAHADAACAAEAAA4Q"
                        "AA4GbnMtZXh0BG5ydDHADMAMAAIAAQAADhAADgZucy1leHQEc3RoMcAMwAwAAgAB"
                        "AAAOEAAJBm5zLWV4dMAMwAwAAgABAAAOEAAOBm5zLWV4dARsZ2ExwAzBaEpCPdYL"
                        "AIEAAACBAAAAAGAIReRVABKpADIjCABFAABzAABAADoR+HPZDQQYwKiqOAA1BqsA"
                        "X7VsMm6FgwABAAAAAAAABV9sZGFwBF90Y3AXRGVmYXVsdC1GaXJzdC1TaXRlLU5h"
                        "bWUGX3NpdGVzAmRjBl9tc2Rjcwt1dGVsc3lzdGVtcwVsb2NhbAAAIQABwWhKQszY"
                        "CwBiAAAAYgAAAAASqQAyIwBgCEXkVQgARQAAVIfwAACAEWqiwKiqONkNBBgGrAA1"
                        "AEB8UfFhAQAAAQAAAAAAAAVfbGRhcARfdGNwAmRjBl9tc2Rjcwt1dGVsc3lzdGVt"
                        "cwVsb2NhbAAAIQABwWhKQmEcDABiAAAAYgAAAABgCEXkVQASqQAyIwgARQAAVAAA"
                        "QAA6EfiS2Q0EGMCoqjgANQasAED3zfFhhYMAAQAAAAAAAAVfbGRhcARfdGNwAmRj"
                        "Bl9tc2Rjcwt1dGVsc3lzdGVtcwVsb2NhbAAAIQABwWhKQoAeDACMAAAAjAAAAAAS"
                        "qQAyIwBgCEXkVQgARQAAfofxAACAEWp3wKiqONkNBBgGrQA1AGp3mINhAQAAAQAA"
                        "AAAAAAVfbGRhcARfdGNwJDA1YjUyOTJiLTM0YjgtNGZiNy04NWEzLThiZWVmNWZk"
                        "MjA2OQdkb21haW5zBl9tc2Rjcwt1dGVsc3lzdGVtcwVsb2NhbAAAIQABwWhKQmRr"
                        "DACMAAAAjAAAAABgCEXkVQASqQAyIwgARQAAfgAAQAA6Efho2Q0EGMCoqjgANQat"
                        "AGrzFINhhYMAAQAAAAAAAAVfbGRhcARfdGNwJDA1YjUyOTJiLTM0YjgtNGZiNy04"
                        "NWEzLThiZWVmNWZkMjA2OQdkb21haW5zBl9tc2Rjcwt1dGVsc3lzdGVtcwVsb2Nh"
                        "bAAAIQABwWhKQvn4DQBTAAAAUwAAAAASqQAyIwBgCEXkVQgARQAARYf1AACAEWqs"
                        "wKiqONkNBBgGrgA1ADEajdBgAQAAAQAAAAAAAAVHUklNTQt1dGVsc3lzdGVtcwVs"
                        "b2NhbAAAAQABwWhKQhU7DgBTAAAAUwAAAABgCEXkVQASqQAyIwgARQAARQAAQAA6"
                        "Efih2Q0EGMCoqjgANQauADGWCdBghYMAAQAAAAAAAAVHUklNTQt1dGVsc3lzdGVt"
                        "cwVsb2NhbAAAAQAByWhKQuJzBQBTAAAAUwAAAAASqQAyIwBgCEXkVQgARQAARYf7"
                        "AACAEWqmwKiqONkNBBgGrwA1ADF0iXZjAQAAAQAAAAAAAAVHUklNTQt1dGVsc3lz"
                        "dGVtcwVsb2NhbAAAAQAByWhKQj+6BQBTAAAAUwAAAABgCEXkVQASqQAyIwgARQAA"
                        "RQAAQAA6Efih2Q0EGMCoqjgANQavADHwBXZjhYMAAQAAAAAAAAVHUklNTQt1dGVs"
                        "c3lzdGVtcwVsb2NhbAAAAQAB",
        "type": "Network Traffic"
    }


class TestArtifactPattern(ObjectTestCase, unittest.TestCase):
    object_type = "ArtifactObjectType"
    klass = Artifact

    _full_dict = {
        "xsi:type": object_type,
        "raw_artifact": {
            "value": "777777076578616D706C6503636F6D",
            "condition": "Contains"
        },
        "type": "Network Traffic"
    }


def _get_data(artifact):
    return artifact.data


def _set_data(artifact, data):
    artifact.data = data


def _get_packed_data(artifact):
    return artifact.packed_data


def _set_packed_data(artifact, packed_data):
    artifact.packed_data = packed_data


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox.bindings.cybox_common as common_binding


class ErrorInstances(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.ErrorInstancesType
    _namespace = 'http://cybox.mitre.org/common-2'

    error_instance = fields.TypedField("Error_Instance", multiple=True)


class Error(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.ErrorType
    _namespace = 'http://cybox.mitre.org/common-2'

    error_type = fields.TypedField("Error_Type")
    error_count = fields.TypedField("Error_Count")
    error_instances = fields.TypedField("Error_Instances", ErrorInstances)


class Errors(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.ErrorsType
    _namespace = 'http://cybox.mitre.org/common-2'

    error = fields.TypedField("Error", Error, multiple=True)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.url_history_object import URLHistory, URLHistoryEntry
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase


class TestUrlHistoryEntry(EntityTestCase, unittest.TestCase):
    klass = URLHistoryEntry

    _full_dict = {
        'url': {
            'value': u('http://www.example.com/index.html'),
            'type': 'URL',
            'xsi:type': 'URIObjectType',
        },
        'hostname': {
            'hostname_value': u('www.example.com'),
            'xsi:type': 'HostnameObjectType',
        },
        'referrer_url': {
            'value': u('http://www.example2.com/index.html'),
            'type': 'URL',
            'xsi:type': 'URIObjectType',
        },
        'page_title': u('An example on URLHistoryEntry'),
        'user_profile_name': u('Default'),
        'visit_count': 5,
        'manually_entered_count': 1,
        'modification_datetime': '2001-01-01T06:56:50+04:00',
        'expiration_datetime': '2001-01-01T06:56:50+04:00',
        'first_visit_datetime': '2001-01-01T06:56:50+04:00',
        'last_visit_datetime': '2001-01-05T06:56:50+04:00',
    }


class TestUrlHistory(ObjectTestCase, unittest.TestCase):
    object_type = "URLHistoryObjectType"
    klass = URLHistory

    _full_dict = {
        'browser_information': {
            'name': 'Google Chrome (64-bit)',
            'vendor': 'Google',
            'version': '80.0.3987.106'
        },
        'url_history_entry': [
            TestUrlHistoryEntry._full_dict
        ],
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.unix_volume_object import UnixVolume
from cybox.test.objects import ObjectTestCase


class TestUnixVolume(ObjectTestCase, unittest.TestCase):
    object_type = "UnixVolumeObjectType"
    klass = UnixVolume

    _full_dict = {
        'is_mounted': True,
        'name': u('sda'),
        'mount_point': u('/boot/efi'),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import fields

import cybox.bindings.user_session_object as user_session_binding
from cybox.common import DateTime, String, ObjectProperties


class UserSession(ObjectProperties):
    _binding = user_session_binding
    _binding_class = user_session_binding.UserSessionObjectType
    _namespace = "http://cybox.mitre.org/objects#UserSessionObject-2"
    _XSI_NS = "UserSessionObj"
    _XSI_TYPE = "UserSessionObjectType"

    effective_group = fields.TypedField("Effective_Group", String)
    effective_group_id = fields.TypedField("Effective_Group_ID", String)
    effective_user = fields.TypedField("Effective_User", String)
    effective_user_id = fields.TypedField("Effective_User_ID", String)
    login_time = fields.TypedField("Login_Time", DateTime)
    logout_time = fields.TypedField("Logout_Time", DateTime)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.dns_record_object import DNSRecord
from cybox.test.objects import ObjectTestCase
from cybox.test.objects.address_test import TestAddress
from cybox.test.objects.uri_test import TestURI


class TestDNSRecord(ObjectTestCase, unittest.TestCase):
    object_type = "DNSRecordObjectType"
    klass = DNSRecord

    _full_dict = {
        'description': 'A description of this object',
        'domain_name': TestURI._full_dict,
        'queried_date': '2001-01-01T06:56:50+04:00',
        'ip_address': TestAddress._full_dict,
        'address_class': 'IPv4',
        'entry_type': 'SRV',
        'record_name': u('vc.example.com'),
        'record_type': 'DNS',
        'ttl': 14400,
        'flags': u('10'),
        'data_length': 13200,
        'record_data': u('Some Record Data'),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import fields

import cybox.bindings.unix_network_route_entry_object as unix_network_route_entry_binding
from cybox.common import String, UnsignedInteger, UnsignedLong
from cybox.objects.network_route_entry_object import NetworkRouteEntry


class UnixNetworkRouteEntry(NetworkRouteEntry):
    _binding = unix_network_route_entry_binding
    _binding_class = unix_network_route_entry_binding.UnixNetworkRouteEntryObjectType
    _namespace = "http://cybox.mitre.org/objects#UnixNetworkRouteEntryObject-2"
    _XSI_NS = "UnixNetworkRouteEntryObj"
    _XSI_TYPE = "UnixNetworkRouteEntryObjectType"

    flags = fields.TypedField("Flags", String)
    mss = fields.TypedField("MSS", UnsignedInteger)
    ref = fields.TypedField("Ref", UnsignedLong)
    use = fields.TypedField("Use", UnsignedLong)
    window = fields.TypedField("Window", UnsignedInteger)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.x509_certificate_object import (SubjectPublicKey,
                                                   RSAPublicKey, Validity,
                                                   X509Cert, X509Certificate,
                                                   X509CertificateSignature,
                                                   X509NonStandardExtensions,
                                                   X509V3Extensions)
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase


class TestValidity(EntityTestCase, unittest.TestCase):
    klass = Validity

    _full_dict = {
        'not_before': '2006-11-17T00:00:00+00:00',
        'not_after': '2036-07-16T23:59:59+00:00',
    }


class TestRSAPublicKey(EntityTestCase, unittest.TestCase):
    klass = RSAPublicKey

    _full_dict = {
        'modulus': u('00:ac:a0:f0:fb:80:59:d4:9c:c7:a4:cf:9d:a1:59:73:09:10:45:0c:0d:2c:6e:68:f1:6c:5b:48:68:49:59:37:fc:0b:33:19:c2:77:7f:cc:10:2d:95:34:1c:e6:eb:4d:09:a7:1c:d2:b8:c9:97:36:02:b7:89:d4:24:5f:06:c0:cc:44:94:94:8d:02:62:6f:eb:5a:dd:11:8d:28:9a:5c:84:90:10:7a:0d:bd:74:66:2f:6a:38:a0:e2:d5:54:44:eb:1d:07:9f:07:ba:6f:ee:e9:fd:4e:0b:29:f5:3e:84:a0:01:f1:9c:ab:f8:1c:7e:89:a4:e8:a1:d8:71:65:0d:a3:51:7b:ee:bc:d2:22:60:0d:b9:5b:9d:df:ba:fc:51:5b:0b:af:98:b2:e9:2e:e9:04:e8:62:87:de:2b:c8:d7:4e:c1:4c:64:1e:dd:cf:87:58:ba:4a:4f:ca:68:07:1d:1c:9d:4a:c6:d5:2f:91:cc:7c:71:72:1c:c5:c0:67:eb:32:fd:c9:92:5c:94:da:85:c0:9b:bf:53:7d:2b:09:f4:8c:9d:91:1f:97:6a:52:cb:de:09:36:a4:77:d8:7b:87:50:44:d5:3e:6e:29:69:fb:39:49:26:1e:09:a5:80:7b:40:2d:eb:e8:27:85:c9:fe:61:fd:7e:e6:7c:97:1d:d5:9d'),
        'exponent': 65537,
    }


class TestSubjectPublicKey(EntityTestCase, unittest.TestCase):
    klass = SubjectPublicKey

    _full_dict = {
        'public_key_algorithm': u('rsaEncryption'),
        'rsa_public_key': TestRSAPublicKey._full_dict,
    }


class TestX509NonStandardExtensions(EntityTestCase, unittest.TestCase):
    klass = X509NonStandardExtensions

    _full_dict = {
        'netscape_comment': u('some netscape comment'),
        'netscape_certificate_type': u('cert type'),
        'old_authority_key_identifier': u('CE:CB'),
        'old_primary_key_attributes': u('CA:TRUE'),
    }


class TestX509V3Extensions(EntityTestCase, unittest.TestCase):
    klass = X509V3Extensions

    _full_dict = {
        'basic_constraints': u('CA:TRUE'),
        'key_usage':  u('Certificate Sign, CRL Sign'),
        'subject_key_identifier': u('7B:5B:45:CF:AF:CE:CB:7A:FD:31:92:1A:6A:B6:F3:46:EB:57:48:50')
    }


class TestX509Cert(EntityTestCase, unittest.TestCase):
    klass = X509Cert

    _full_dict = {
        'version': 3,
        'serial_number': u('34:4e:d5:57:20:d5:ed:ec:49:f4:2f:ce:37:db:2b:6d'),
        'signature_algorithm': u('sha1WithRSAEncryption'),
        'issuer': u('C = US, O = "thawte, Inc.", OU = Certification Services Division, OU = "(c) 2006 thawte, Inc. - For authorized use only", CN = thawte Primary Root CA'),
        'validity': TestValidity._full_dict,
        'subject': u('C = US, O = "thawte, Inc.", OU = Certification Services Division, OU = "(c) 2006 thawte, Inc. - For authorized use only", CN = thawte Primary Root CA'),
        'subject_public_key': TestSubjectPublicKey._full_dict,
        'standard_extensions': TestX509V3Extensions._full_dict,
    }


class TestX509CertificateSignature(EntityTestCase, unittest.TestCase):
    klass = X509CertificateSignature

    _full_dict = {
        'signature_algorithm': u('sha1WithRSAEncryption'),
        'signature': u('79:11:c0:4b:b3:91:b6:fc:f0:e9:67:d4:0d:6e:45:be:55:e8:93:d2:ce:03:3f:ed:da:25:b0:1d:57:cb:1e:3a:76:a0:4c:ec:50:76:e8:64:72:0c:a4:a9:f1:b8:8b:d6:d6:87:84:bb:32:e5:41:11:c0:77:d9:b3:60:9d:eb:1b:d5:d1:6e:44:44:a9:a6:01:ec:55:62:1d:77:b8:5c:8e:48:49:7c:9c:3b:57:11:ac:ad:73:37:8e:2f:78:5c:90:68:47:d9:60:60:e6:fc:07:3d:22:20:17:c4:f7:16:e9:c4:d8:72:f9:c8:73:7c:df:16:2f:15:a9:3e:fd:6a:27:b6:a1:eb:5a:ba:98:1f:d5:e3:4d:64:0a:9d:13:c8:61:ba:f5:39:1c:87:ba:b8:bd:7b:22:7f:f6:fe:ac:40:79:e5:ac:10:6f:3d:8f:1b:79:76:8b:c4:37:b3:21:18:84:e5:36:00:eb:63:20:99:b9:e9:fe:33:04:bb:41:c8:c1:02:f9:44:63:20:9e:81:ce:42:d3:d6:3f:2c:76:d3:63:9c:59:dd:8f:a6:e1:0e:a0:2e:41:f7:2e:95:47:cf:bc:fd:33:f3:f6:0b:61:7e:7e:91:2b:81:47:c2:27:30:ee:a7:10:5d:37:8f:5c:39:2b:e4:04:f0:7b:8d:56:8c:68'),
    }


class TestX509Certificate(ObjectTestCase, unittest.TestCase):
    object_type = "X509CertificateObjectType"
    klass = X509Certificate

    _full_dict = {
        'certificate': TestX509Cert._full_dict,
        'raw_certificate': u('''-----BEGIN CERTIFICATE-----
MIIEIDCCAwigAwIBAgIQNE7VVyDV7exJ9C/ON9srbTANBgkqhkiG9w0BAQUFADCB
qTELMAkGA1UEBhMCVVMxFTATBgNVBAoTDHRoYXd0ZSwgSW5jLjEoMCYGA1UECxMf
Q2VydGlmaWNhdGlvbiBTZXJ2aWNlcyBEaXZpc2lvbjE4MDYGA1UECxMvKGMpIDIw
MDYgdGhhd3RlLCBJbmMuIC0gRm9yIGF1dGhvcml6ZWQgdXNlIG9ubHkxHzAdBgNV
BAMTFnRoYXd0ZSBQcmltYXJ5IFJvb3QgQ0EwHhcNMDYxMTE3MDAwMDAwWhcNMzYw
NzE2MjM1OTU5WjCBqTELMAkGA1UEBhMCVVMxFTATBgNVBAoTDHRoYXd0ZSwgSW5j
LjEoMCYGA1UECxMfQ2VydGlmaWNhdGlvbiBTZXJ2aWNlcyBEaXZpc2lvbjE4MDYG
A1UECxMvKGMpIDIwMDYgdGhhd3RlLCBJbmMuIC0gRm9yIGF1dGhvcml6ZWQgdXNl
IG9ubHkxHzAdBgNVBAMTFnRoYXd0ZSBQcmltYXJ5IFJvb3QgQ0EwggEiMA0GCSqG
SIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsoPD7gFnUnMekz52hWXMJEEUMDSxuaPFs
W0hoSVk3/AszGcJ3f8wQLZU0HObrTQmnHNK4yZc2AreJ1CRfBsDMRJSUjQJib+ta
3RGNKJpchJAQeg29dGYvajig4tVUROsdB58Hum/u6f1OCyn1PoSgAfGcq/gcfomk
6KHYcWUNo1F77rzSImANuVud37r8UVsLr5iy6S7pBOhih94ryNdOwUxkHt3Ph1i6
Sk/KaAcdHJ1KxtUvkcx8cXIcxcBn6zL9yZJclNqFwJu/U30rCfSMnZEfl2pSy94J
NqR32HuHUETVPm4pafs5SSYeCaWAe0At6+gnhcn+Yf1+5nyXHdWdAgMBAAGjQjBA
MA8GA1UdEwEB/wQFMAMBAf8wDgYDVR0PAQH/BAQDAgEGMB0GA1UdDgQWBBR7W0XP
r87Lev0xkhpqtvNG61dIUDANBgkqhkiG9w0BAQUFAAOCAQEAeRHAS7ORtvzw6WfU
DW5FvlXok9LOAz/t2iWwHVfLHjp2oEzsUHboZHIMpKnxuIvW1oeEuzLlQRHAd9mz
YJ3rG9XRbkREqaYB7FViHXe4XI5ISXycO1cRrK1zN44veFyQaEfZYGDm/Ac9IiAX
xPcW6cTYcvnIc3zfFi8VqT79aie2oetaupgf1eNNZAqdE8hhuvU5HIe6uL17In/2
/qxAeeWsEG89jxt5dovEN7MhGITlNgDrYyCZuen+MwS7QcjBAvlEYyCegc5C09Y/
LHbTY5xZ3Y+m4Q6gLkH3LpVHz7z9M/P2C2F+fpErgUfCJzDupxBdN49cOSvkBPB7
jVaMaA==
-----END CERTIFICATE-----'''),
        'certificate_signature': TestX509CertificateSignature._full_dict,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.unix_file_object import UnixFile, UnixFilePermissions
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase


class TestUnixFilePermissions(EntityTestCase, unittest.TestCase):
    klass = UnixFilePermissions
    _full_dict = {
        'suid': True,
        'sgid': False,
        'uread': True,
        'uwrite': True,
        'uexec': True,
        'gread': True,
        'gwrite': False,
        'gexec': False,
        'oread': True,
        'owrite': False,
        'oexec': False,
    }


class TestUnixFile(ObjectTestCase, unittest.TestCase):
    object_type = "UnixFileObjectType"
    klass = UnixFile

    _full_dict = {
        'group_owner': u('samplegroup'),
        'inode': 6755399441071048,
        'type': u('regularfile'),
        'permissions': TestUnixFilePermissions._full_dict,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.win_system_object import GlobalFlag, GlobalFlagList, WinSystem
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase
from cybox.test.objects.win_handle_test import TestWinHandle


class TestGlobalFlag(EntityTestCase, unittest.TestCase):
    klass = GlobalFlag

    _full_dict = {
        'abbreviation': u('tst'),
        'destination': u('C:/TEST'),
        'hexadecimal_value': u('0x1'),
        'symbolic_name': u('somesymbol'),
    }


class TestGlobalFlagList(EntityTestCase, unittest.TestCase):
    klass = GlobalFlagList

    _full_dict = [
        TestGlobalFlag._full_dict,
        TestGlobalFlag._full_dict,
    ]


class TestWinSystem(ObjectTestCase, unittest.TestCase):
    object_type = "WindowsSystemObjectType"
    klass = WinSystem

    _full_dict = {
        'domain': [u('WORKINGGROUP')],
        'global_flag_list': TestGlobalFlagList._full_dict,
        'netbios_name': u('joe.local'),
        'open_handle_list': [TestWinHandle._full_dict],
        'product_id': u('00330-80000-00000-AA880'),
        'product_name': u('Windows 10'),
        'registered_organization': u('Fabrikam'),
        'registered_owner': u('Joe'),
        'windows_directory': u('C:\\WINDOWS'),
        'windows_system_directory': u('C:\\WINDOWS\\system32'),
        'windows_temp_directory': u('C:\\TEMP'),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox.bindings.cybox_common as common_binding
from cybox.common.platform_specification import PlatformSpecification


class CompilerInformalDescription(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.CompilerInformalDescriptionType
    _namespace = 'http://cybox.mitre.org/common-2'

    compiler_name = fields.TypedField("Compiler_Name")
    compiler_version = fields.TypedField("Compiler_Version")


class Compiler(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.CompilerType
    _namespace = 'http://cybox.mitre.org/common-2'

    compiler_informal_description = fields.TypedField("Compiler_Informal_Description", CompilerInformalDescription)
    compiler_platform_specification = fields.TypedField("Compiler_Platform_Specification", PlatformSpecification)


class Compilers(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.CompilersType
    _namespace = 'http://cybox.mitre.org/common-2'

    compiler = fields.TypedField("Compiler", Compiler, multiple=True)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox.bindings.cybox_common as common_binding
from cybox.common.structured_text import StructuredText


class Dependency(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.DependencyType
    _namespace = 'http://cybox.mitre.org/common-2'

    dependency_type = fields.TypedField("Dependency_Type")
    dependency_description = fields.TypedField("Dependency_Description", StructuredText)


class Dependencies(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.DependenciesType
    _namespace = 'http://cybox.mitre.org/common-2'

    dependency = fields.TypedField("Dependency", Dependency, multiple=True)



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox.namespaces import Namespace, NamespaceSet, register_namespace

NS_CYBOX_CORE = Namespace('http://cybox.mitre.org/cybox-2', 'cybox', 'http://cybox.mitre.org/XMLSchema/core/2.1/cybox_core.xsd')
NS_CYBOX_COMMON = Namespace('http://cybox.mitre.org/common-2', 'cyboxCommon', 'http://cybox.mitre.org/XMLSchema/common/2.1/cybox_common.xsd')
NS_CYBOX_VOCABS = Namespace('http://cybox.mitre.org/default_vocabularies-2', 'cyboxVocabs', 'http://cybox.mitre.org/XMLSchema/default_vocabularies/2.1/cybox_default_vocabularies.xsd')
NS_ACCOUNT_OBJECT = Namespace('http://cybox.mitre.org/objects#AccountObject-2', 'AccountObj', 'http://cybox.mitre.org/XMLSchema/objects/Account/2.1/Account_Object.xsd')
NS_ADDRESS_OBJECT = Namespace('http://cybox.mitre.org/objects#AddressObject-2', 'AddressObj', 'http://cybox.mitre.org/XMLSchema/objects/Address/2.1/Address_Object.xsd')
NS_API_OBJECT = Namespace('http://cybox.mitre.org/objects#APIObject-2', 'APIObj', 'http://cybox.mitre.org/XMLSchema/objects/API/2.1/API_Object.xsd')
NS_ARCHIVEFILE_OBJECT = Namespace('http://cybox.mitre.org/objects#ArchiveFileObject-1', 'ArchiveFileObj', 'http://cybox.mitre.org/XMLSchema/objects/Archive_File/1.0/Archive_File_Object.xsd')
NS_ARPCACHE_OBJECT = Namespace('http://cybox.mitre.org/objects#ARPCacheObject-1', 'ARPCacheObj', 'http://cybox.mitre.org/XMLSchema/objects/ARP_Cache/1.0/ARP_Cache_Object.xsd')
NS_ARTIFACT_OBJECT = Namespace('http://cybox.mitre.org/objects#ArtifactObject-2', 'ArtifactObj', 'http://cybox.mitre.org/XMLSchema/objects/Artifact/2.1/Artifact_Object.xsd')
NS_AS_OBJECT = Namespace('http://cybox.mitre.org/objects#ASObject-1', 'ASObj', 'http://cybox.mitre.org/XMLSchema/objects/AS/1.0/AS_Object.xsd')
NS_CODE_OBJECT = Namespace('http://cybox.mitre.org/objects#CodeObject-2', 'CodeObj', 'http://cybox.mitre.org/XMLSchema/objects/Code/2.1/Code_Object.xsd')
NS_CUSTOM_OBJECT = Namespace('http://cybox.mitre.org/objects#CustomObject-1', 'CustomObj', 'http://cybox.mitre.org/XMLSchema/objects/Custom/1.1/Custom_Object.xsd')
NS_DEVICE_OBJECT = Namespace('http://cybox.mitre.org/objects#DeviceObject-2', 'DeviceObj', 'http://cybox.mitre.org/XMLSchema/objects/Device/2.1/Device_Object.xsd')
NS_DISK_OBJECT = Namespace('http://cybox.mitre.org/objects#DiskObject-2', 'DiskObj', 'http://cybox.mitre.org/XMLSchema/objects/Disk/2.1/Disk_Object.xsd')
NS_DISKPARTITION_OBJECT = Namespace('http://cybox.mitre.org/objects#DiskPartitionObject-2', 'DiskPartitionObj', 'http://cybox.mitre.org/XMLSchema/objects/Disk_Partition/2.1/Disk_Partition_Object.xsd')
NS_DNSCACHE_OBJECT = Namespace('http://cybox.mitre.org/objects#DNSCacheObject-2', 'DNSCacheObj', 'http://cybox.mitre.org/XMLSchema/objects/DNS_Cache/2.1/DNS_Cache_Object.xsd')
NS_DNSQUERY_OBJECT = Namespace('http://cybox.mitre.org/objects#DNSQueryObject-2', 'DNSQueryObj', 'http://cybox.mitre.org/XMLSchema/objects/DNS_Query/2.1/DNS_Query_Object.xsd')
NS_DNSRECORD_OBJECT = Namespace('http://cybox.mitre.org/objects#DNSRecordObject-2', 'DNSRecordObj', 'http://cybox.mitre.org/XMLSchema/objects/DNS_Record/2.1/DNS_Record_Object.xsd')
NS_DOMAINNAME_OBJECT = Namespace('http://cybox.mitre.org/objects#DomainNameObject-1', 'DomainNameObj', 'http://cybox.mitre.org/XMLSchema/objects/Domain_Name/1.0/Domain_Name_Object.xsd')
NS_EMAILMESSAGE_OBJECT = Namespace('http://cybox.mitre.org/objects#EmailMessageObject-2', 'EmailMessageObj', 'http://cybox.mitre.org/XMLSchema/objects/Email_Message/2.1/Email_Message_Object.xsd')
NS_FILE_OBJECT = Namespace('http://cybox.mitre.org/objects#FileObject-2', 'FileObj', 'http://cybox.mitre.org/XMLSchema/objects/File/2.1/File_Object.xsd')
NS_GUIDIALOGBOX_OBJECT = Namespace('http://cybox.mitre.org/objects#GUIDialogboxObject-2', 'GUIDialogBoxObj', 'http://cybox.mitre.org/XMLSchema/objects/GUI_Dialogbox/2.1/GUI_Dialogbox_Object.xsd')
NS_GUI_OBJECT = Namespace('http://cybox.mitre.org/objects#GUIObject-2', 'GUIObj', 'http://cybox.mitre.org/XMLSchema/objects/GUI/2.1/GUI_Object.xsd')
NS_GUIWINDOW_OBJECT = Namespace('http://cybox.mitre.org/objects#GUIWindowObject-2', 'GUIWindowObj', 'http://cybox.mitre.org/XMLSchema/objects/GUI_Window/2.1/GUI_Window_Object.xsd')
NS_HOSTNAME_OBJECT = Namespace('http://cybox.mitre.org/objects#HostnameObject-1', 'HostnameObj', 'http://cybox.mitre.org/XMLSchema/objects/Hostname/1.0/Hostname_Object.xsd')
NS_HTTPSESSION_OBJECT = Namespace('http://cybox.mitre.org/objects#HTTPSessionObject-2', 'HTTPSessionObj', 'http://cybox.mitre.org/XMLSchema/objects/HTTP_Session/2.1/HTTP_Session_Object.xsd')
NS_IMAGEFILE_OBJECT = Namespace('http://cybox.mitre.org/objects#ImageFileObject-1', 'ImageFileObj', 'http://cybox.mitre.org/XMLSchema/objects/Image_File/1.0/Image_File_Object.xsd')
NS_LIBRARY_OBJECT = Namespace('http://cybox.mitre.org/objects#LibraryObject-2', 'LibraryObj', 'http://cybox.mitre.org/XMLSchema/objects/Library/2.1/Library_Object.xsd')
NS_LINK_OBJECT = Namespace('http://cybox.mitre.org/objects#LinkObject-1', 'LinkObj', 'http://cybox.mitre.org/XMLSchema/objects/Link/1.1/Link_Object.xsd')
NS_LINUXPACKAGE_OBJECT = Namespace('http://cybox.mitre.org/objects#LinuxPackageObject-2', 'LinuxPackageObj', 'http://cybox.mitre.org/XMLSchema/objects/Linux_Package/2.1/Linux_Package_Object.xsd')
NS_MEMORY_OBJECT = Namespace('http://cybox.mitre.org/objects#MemoryObject-2', 'MemoryObj', 'http://cybox.mitre.org/XMLSchema/objects/Memory/2.1/Memory_Object.xsd')
NS_MUTEX_OBJECT = Namespace('http://cybox.mitre.org/objects#MutexObject-2', 'MutexObj', 'http://cybox.mitre.org/XMLSchema/objects/Mutex/2.1/Mutex_Object.xsd')
NS_NETWORKCONNECTION_OBJECT = Namespace('http://cybox.mitre.org/objects#NetworkConnectionObject-2', 'NetworkConnectionObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Connection/2.1/Network_Connection_Object.xsd')
NS_NETWORKFLOW_OBJECT = Namespace('http://cybox.mitre.org/objects#NetworkFlowObject-2', 'NetFlowObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Flow/2.1/Network_Flow_Object.xsd')
NS_NETWORKROUTEENTRY_OBJECT = Namespace('http://cybox.mitre.org/objects#NetworkRouteEntryObject-2', 'NetworkRouteEntryObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Route_Entry/2.1/Network_Route_Entry_Object.xsd')
NS_NETWORKROUTE_OBJECT = Namespace('http://cybox.mitre.org/objects#NetworkRouteObject-2', 'NetworkRouteObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Route/2.1/Network_Route_Object.xsd')
NS_NETWORKSOCKET_OBJECT = Namespace('http://cybox.mitre.org/objects#NetworkSocketObject-2', 'NetworkSocketObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Socket/2.1/Network_Socket_Object.xsd')
NS_NETWORKSUBNET_OBJECT = Namespace('http://cybox.mitre.org/objects#NetworkSubnetObject-2', 'NetworkSubnetObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Subnet/2.1/Network_Subnet_Object.xsd')
NS_PACKET_OBJECT = Namespace('http://cybox.mitre.org/objects#PacketObject-2', 'PacketObj', 'http://cybox.mitre.org/XMLSchema/objects/Network_Packet/2.1/Network_Packet_Object.xsd')
NS_PDFFILE_OBJECT = Namespace('http://cybox.mitre.org/objects#PDFFileObject-1', 'PDFFileObj', 'http://cybox.mitre.org/XMLSchema/objects/PDF_File/1.1/PDF_File_Object.xsd')
NS_PIPE_OBJECT = Namespace('http://cybox.mitre.org/objects#PipeObject-2', 'PipeObj', 'http://cybox.mitre.org/XMLSchema/objects/Pipe/2.1/Pipe_Object.xsd')
NS_PORT_OBJECT = Namespace('http://cybox.mitre.org/objects#PortObject-2', 'PortObj', 'http://cybox.mitre.org/XMLSchema/objects/Port/2.1/Port_Object.xsd')
NS_PROCESS_OBJECT = Namespace('http://cybox.mitre.org/objects#ProcessObject-2', 'ProcessObj', 'http://cybox.mitre.org/XMLSchema/objects/Process/2.1/Process_Object.xsd')
NS_PRODUCT_OBJECT = Namespace('http://cybox.mitre.org/objects#ProductObject-2', 'ProductObj', 'http://cybox.mitre.org/XMLSchema/objects/Product/2.1/Product_Object.xsd')
NS_SEMAPHORE_OBJECT = Namespace('http://cybox.mitre.org/objects#SemaphoreObject-2', 'SemaphoreObj', 'http://cybox.mitre.org/XMLSchema/objects/Semaphore/2.1/Semaphore_Object.xsd')
NS_SMSMESSAGE_OBJECT = Namespace('http://cybox.mitre.org/objects#SMSMessageObject-1', 'SMSMessageObj', 'http://cybox.mitre.org/XMLSchema/objects/SMS_Message/1.0/SMS_Message_Object.xsd')
NS_SOCKETADDRESS_OBJECT = Namespace('http://cybox.mitre.org/objects#SocketAddressObject-1', 'SocketAddressObj', 'http://cybox.mitre.org/XMLSchema/objects/Socket_Address/1.1/Socket_Address_Object.xsd')
NS_SYSTEM_OBJECT = Namespace('http://cybox.mitre.org/objects#SystemObject-2', 'SystemObj', 'http://cybox.mitre.org/XMLSchema/objects/System/2.1/System_Object.xsd')
NS_UNIXFILE_OBJECT = Namespace('http://cybox.mitre.org/objects#UnixFileObject-2', 'UnixFileObj', 'http://cybox.mitre.org/XMLSchema/objects/Unix_File/2.1/Unix_File_Object.xsd')
NS_UNIXNETWORKROUTEENTRY_OBJECT = Namespace('http://cybox.mitre.org/objects#UnixNetworkRouteEntryObject-2', 'UnixNetworkRouteEntryObj', 'http://cybox.mitre.org/XMLSchema/objects/Unix_Network_Route_Entry/2.1/Unix_Network_Route_Entry_Object.xsd')
NS_UNIXPIPE_OBJECT = Namespace('http://cybox.mitre.org/objects#UnixPipeObject-2', 'UnixPipeObj', 'http://cybox.mitre.org/XMLSchema/objects/Unix_Pipe/2.1/Unix_Pipe_Object.xsd')
NS_UNIXPROCESS_OBJECT = Namespace('http://cybox.mitre.org/objects#UnixProcessObject-2', 'UnixProcessObj', 'http://cybox.mitre.org/XMLSchema/objects/Unix_Process/2.1/Unix_Process_Object.xsd')
NS_UNIXUSERACCOUNT_OBJECT = Namespace('http://cybox.mitre.org/objects#UnixUserAccountObject-2', 'UnixUserAccountObj', 'http://cybox.mitre.org/XMLSchema/objects/Unix_User_Account/2.1/Unix_User_Account_Object.xsd')
NS_UNIXVOLUME_OBJECT = Namespace('http://cybox.mitre.org/objects#UnixVolumeObject-2', 'UnixVolumeObj', 'http://cybox.mitre.org/XMLSchema/objects/Unix_Volume/2.1/Unix_Volume_Object.xsd')
NS_URI_OBJECT = Namespace('http://cybox.mitre.org/objects#URIObject-2', 'URIObj', 'http://cybox.mitre.org/XMLSchema/objects/URI/2.1/URI_Object.xsd')
NS_URLHISTORY_OBJECT = Namespace('http://cybox.mitre.org/objects#URLHistoryObject-1', 'URLHistoryObj', 'http://cybox.mitre.org/XMLSchema/objects/URL_History/1.0/URL_History_Object.xsd')
NS_USERACCOUNT_OBJECT = Namespace('http://cybox.mitre.org/objects#UserAccountObject-2', 'UserAccountObj', 'http://cybox.mitre.org/XMLSchema/objects/User_Account/2.1/User_Account_Object.xsd')
NS_USERSESSION_OBJECT = Namespace('http://cybox.mitre.org/objects#UserSessionObject-2', 'UserSessionObj', 'http://cybox.mitre.org/XMLSchema/objects/User_Session/2.1/User_Session_Object.xsd')
NS_VOLUME_OBJECT = Namespace('http://cybox.mitre.org/objects#VolumeObject-2', 'VolumeObj', 'http://cybox.mitre.org/XMLSchema/objects/Volume/2.1/Volume_Object.xsd')
NS_WHOIS_OBJECT = Namespace('http://cybox.mitre.org/objects#WhoisObject-2', 'WhoisObj', 'http://cybox.mitre.org/XMLSchema/objects/Whois/2.1/Whois_Object.xsd')
NS_WINCOMPUTERACCOUNT_OBJECT = Namespace('http://cybox.mitre.org/objects#WinComputerAccountObject-2', 'WinComputerAccountObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Computer_Account/2.1/Win_Computer_Account_Object.xsd')
NS_WINCRITICALSECTION_OBJECT = Namespace('http://cybox.mitre.org/objects#WinCriticalSectionObject-2', 'WinCriticalSectionObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Critical_Section/2.1/Win_Critical_Section_Object.xsd')
NS_WINDRIVER_OBJECT = Namespace('http://cybox.mitre.org/objects#WinDriverObject-3', 'WinDriverObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Driver/3.0/Win_Driver_Object.xsd')
NS_WINEVENTLOG_OBJECT = Namespace('http://cybox.mitre.org/objects#WinEventLogObject-2', 'WinEventLogObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Event_Log/2.1/Win_Event_Log_Object.xsd')
NS_WINEVENT_OBJECT = Namespace('http://cybox.mitre.org/objects#WinEventObject-2', 'WinEventObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Event/2.1/Win_Event_Object.xsd')
NS_WINEXECUTABLEFILE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinExecutableFileObject-2', 'WinExecutableFileObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Executable_File/2.1/Win_Executable_File_Object.xsd')
NS_WINFILE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinFileObject-2', 'WinFileObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_File/2.1/Win_File_Object.xsd')
NS_WINFILEMAPPING_OBJECT = Namespace('http://cybox.mitre.org/objects#WinFilemappingObject-1', 'WinFilemappingObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Filemapping/1.0/Win_Filemapping_Object.xsd')
NS_WINHANDLE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinHandleObject-2', 'WinHandleObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Handle/2.1/Win_Handle_Object.xsd')
NS_WINHOOK_OBJECT = Namespace('http://cybox.mitre.org/objects#WinHookObject-1', 'WinHookObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Hook/1.0/Win_Hook_Object.xsd')
NS_WINKERNELHOOK_OBJECT = Namespace('http://cybox.mitre.org/objects#WinKernelHookObject-2', 'WinKernelHookObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Kernel_Hook/2.1/Win_Kernel_Hook_Object.xsd')
NS_WINKERNEL_OBJECT = Namespace('http://cybox.mitre.org/objects#WinKernelObject-2', 'WinKernelObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Kernel/2.1/Win_Kernel_Object.xsd')
NS_WINMAILSLOT_OBJECT = Namespace('http://cybox.mitre.org/objects#WinMailslotObject-2', 'WinMailslotObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Mailslot/2.1/Win_Mailslot_Object.xsd')
NS_WINMEMORYPAGEREGION_OBJECT = Namespace('http://cybox.mitre.org/objects#WinMemoryPageRegionObject-2', 'WinMemoryPageRegionObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Memory_Page_Region/2.1/Win_Memory_Page_Region_Object.xsd')
NS_WINMUTEX_OBJECT = Namespace('http://cybox.mitre.org/objects#WinMutexObject-2', 'WinMutexObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Mutex/2.1/Win_Mutex_Object.xsd')
NS_WINNETWORKROUTEENTRY_OBJECT = Namespace('http://cybox.mitre.org/objects#WinNetworkRouteEntryObject-2', 'WinNetworkRouteEntryObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Network_Route_Entry/2.1/Win_Network_Route_Entry_Object.xsd')
NS_WINNETWORKSHARE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinNetworkShareObject-2', 'WinNetworkShareObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Network_Share/2.1/Win_Network_Share_Object.xsd')
NS_WINPIPE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinPipeObject-2', 'WinPipeObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Pipe/2.1/Win_Pipe_Object.xsd')
NS_WINPREFETCH_OBJECT = Namespace('http://cybox.mitre.org/objects#WinPrefetchObject-2', 'WinPrefetchObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Prefetch/2.1/Win_Prefetch_Object.xsd')
NS_WINPROCESS_OBJECT = Namespace('http://cybox.mitre.org/objects#WinProcessObject-2', 'WinProcessObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Process/2.1/Win_Process_Object.xsd')
NS_WINREGISTRYKEY_OBJECT = Namespace('http://cybox.mitre.org/objects#WinRegistryKeyObject-2', 'WinRegistryKeyObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Registry_Key/2.1/Win_Registry_Key_Object.xsd')
NS_WINSEMAPHORE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinSemaphoreObject-2', 'WinSemaphoreObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Semaphore/2.1/Win_Semaphore_Object.xsd')
NS_WINSERVICE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinServiceObject-2', 'WinServiceObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Service/2.1/Win_Service_Object.xsd')
NS_WINSYSTEM_OBJECT = Namespace('http://cybox.mitre.org/objects#WinSystemObject-2', 'WinSystemObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_System/2.1/Win_System_Object.xsd')
NS_WINSYSTEMRESTORE_OBJECT = Namespace('http://cybox.mitre.org/objects#WinSystemRestoreObject-2', 'WinSystemRestoreObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_System_Restore/2.1/Win_System_Restore_Object.xsd')
NS_WINTASK_OBJECT = Namespace('http://cybox.mitre.org/objects#WinTaskObject-2', 'WinTaskObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Task/2.1/Win_Task_Object.xsd')
NS_WINTHREAD_OBJECT = Namespace('http://cybox.mitre.org/objects#WinThreadObject-2', 'WinThreadObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Thread/2.1/Win_Thread_Object.xsd')
NS_WINUSERACCOUNT_OBJECT = Namespace('http://cybox.mitre.org/objects#WinUserAccountObject-2', 'WinUserAccountObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_User_Account/2.1/Win_User_Account_Object.xsd')
NS_WINVOLUME_OBJECT = Namespace('http://cybox.mitre.org/objects#WinVolumeObject-2', 'WinVolumeObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Volume/2.1/Win_Volume_Object.xsd')
NS_WINWAITABLETIMER_OBJECT = Namespace('http://cybox.mitre.org/objects#WinWaitableTimerObject-2', 'WinWaitableTimerObj', 'http://cybox.mitre.org/XMLSchema/objects/Win_Waitable_Timer/2.1/Win_Waitable_Timer_Object.xsd')
NS_X509CERTIFICATE_OBJECT = Namespace('http://cybox.mitre.org/objects#X509CertificateObject-2', 'X509CertificateObj', 'http://cybox.mitre.org/XMLSchema/objects/X509_Certificate/2.1/X509_Certificate_Object.xsd')

CYBOX_NAMESPACES = NamespaceSet()

# Magic to automatically register all Namespaces defined in this module.
for k, v in dict(globals()).items():
    if k.startswith('NS_'):
        register_namespace(v)
        CYBOX_NAMESPACES.add_namespace(v)



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from cybox.common import Location
import cybox.test


class TestLocation(cybox.test.EntityTestCase, unittest.TestCase):
    klass = Location
    _full_dict = {
        'name': "Bedford, MA",
        'id': "example:12345",
    }



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.unix_pipe_object import UnixPipe
from cybox.test.objects import ObjectTestCase


class TestUnixPipe(ObjectTestCase, unittest.TestCase):
    object_type = "UnixPipeObjectType"
    klass = UnixPipe

    _full_dict = {
        'name': u("unix-pipe1"),
        'permission_mode': "0000ccff",
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox.bindings.cybox_common as common_binding
from cybox.common.object_properties import ObjectPropertiesFactory, ObjectProperties
from cybox.common.time import DateTimeWithPrecision


class ExecutionEnvironment(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.ExecutionEnvironmentType
    _namespace = 'http://cybox.mitre.org/common-2'

    system = fields.TypedField("System", ObjectProperties, factory=ObjectPropertiesFactory)
    user_account_info = fields.TypedField("User_Account_Info", ObjectProperties, factory=ObjectPropertiesFactory)
    command_line = fields.TypedField("Command_Line")
    start_time = fields.TypedField("Start_Time", DateTimeWithPrecision)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.unix_process_object import FileDescriptorList, UnixProcess, UnixProcessStatus
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase


class TestFileDescriptorList(EntityTestCase, unittest.TestCase):
    klass = FileDescriptorList

    _full_dict = [
        [345, 1345],
    ]


class TestUnixProcessStatus(EntityTestCase, unittest.TestCase):
    klass = UnixProcessStatus

    _full_dict = {
        'current_status': u('Running'),
        'timestamp': '2001-01-01T06:56:50+04:00',
        'xsi:type': 'UnixProcessObj:UnixProcessStatusType',
    }


class TestUnixProcess(ObjectTestCase, unittest.TestCase):
    object_type = "UnixProcessObjectType"
    klass = UnixProcess

    _full_dict = {
        'open_file_descriptor_list': TestFileDescriptorList._full_dict,
        'status': TestUnixProcessStatus._full_dict,
        'ruid': 3485,
        'priority': 20,
        'session_id': 2345,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.unix_user_account_object import UnixUserAccount
from cybox.test.objects import ObjectTestCase


class TestUnixUserAccount(ObjectTestCase, unittest.TestCase):
    object_type = "UnixUserAccountObjectType"
    klass = UnixUserAccount

    _full_dict = {
        # Account-specific fields
        'disabled': False,
        'locked_out': True,
        'description': u('An UNIX account'),
        'domain': u('ADMIN'),
        'group_list': [
            {
                'group_id': 12345,
                'xsi:type': 'UnixGroupType'
            }
        ],
        'privilege_list': [
            {
                'permissions_mask': u("rwx"),
                'xsi:type': 'UnixPrivilegeType'
            }
        ],
        'password_required': True,
        'full_name': u("Guido van Rossum"),
        'home_directory': u("/home/guido/"),
        'last_login': "2001-01-01T06:56:50+04:00",
        'script_path': u("/bin/bash"),
        'username': u("guido"),
        'user_password_age': u("P90D"),
        # UnixUser-specific fields
        'group_id': 123,
        'user_id': 7874,
        'login_shell': u("/etc/profile"),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.network_flow_object import (
    BidirectionalRecord, IPFIXDataSet, IPFIXTemplateRecord, IPFIXDataRecord,
    IPFIXMessage, IPFIXSet, IPFIXMessageHeader, FlowDataRecord,
    FlowCollectionElement, OptionsDataRecord, OptionCollectionElement,
    IPFIXSetHeader, IPFIXOptionsTemplateRecord,
    IPFIXOptionsTemplateRecordHeader, IPFIXOptionsTemplateSet,
    IPFIXTemplateRecordFieldSpecifiers, IPFIXTemplateRecordHeader,
    IPFIXTemplateSet, NetflowV5Packet, NetflowV5FlowHeader,
    NetflowV5FlowRecord, NetflowV9DataFlowSet, NetflowV9PacketHeader,
    NetflowV9ExportPacket, NetflowV9OptionsTemplateFlowSet, NetflowV9Field,
    NetflowV9FlowSet, NetflowV9DataRecord, NetflowV9TemplateFlowSet,
    NetflowV9TemplateRecord, NetflowV9OptionsTemplateRecord, NetworkFlow,
    NetworkFlowLabel, NetworkLayerInfo, UnidirectionalRecord, SiLKRecord,
    SiLKSensorInfo, SiLKFlowAttributes, SiLKAddress, SiLKSensorClass,
    SiLKSensorDirection, YAFReverseFlow, YAFRecord, YAFFlow, YAFTCPFlow
)
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase
from cybox.test.objects.address_test import TestAddress
from cybox.test.objects.network_packet_test import TestTCPFlags
from cybox.test.objects.socket_address_test import TestSocketAddress


class TestNetworkFlowLabel(EntityTestCase, unittest.TestCase):
    klass = NetworkFlowLabel

    _full_dict = {
        'ingress_interface_index': 2,
        'egress_interface_index': 3,
        'src_socket_address': TestSocketAddress._full_dict,
        'dest_socket_address': TestSocketAddress._full_dict,
        'ip_protocol': 'TCP',
    }


class TestNetworkLayerInfo(EntityTestCase, unittest.TestCase):
    klass = NetworkLayerInfo

    _full_dict = {
        'src_socket_address': TestSocketAddress._full_dict,
        'dest_socket_address': TestSocketAddress._full_dict,
        'ip_protocol': 'TCP',
    }


class TestYAFTCPFlow(EntityTestCase, unittest.TestCase):
    klass = YAFTCPFlow

    _full_dict = {
        'tcp_sequence_number': 5,
        'initial_tcp_flags': TestTCPFlags._full_dict,
        'union_tcp_flags': u('0C'),
    }


class TestYAFFlow(EntityTestCase, unittest.TestCase):
    klass = YAFFlow

    _full_dict = {
        'flow_start_milliseconds': 1582060813,
        'flow_end_milliseconds': 1582060900,
        'octet_total_count': 144,
        'packet_total_count': 100,
        'flow_end_reason': u('0C'),
        'silk_app_label': 53,
        'payload_entropy': 34,
        'ml_app_label': u('0C'),
        'tcp_flow': TestYAFTCPFlow._full_dict,
        'vlan_id_mac_addr': TestAddress._full_dict,
        'passive_os_fingerprinting': {
            'description': u("The best platform"),
            'identifier': [
                u("value1")
            ]
        },
        'first_packet_banner': u('00'),
        'second_packet_banner': u('0A'),
        'n_bytes_payload': u('EC'),
    }


class TestYAFReverseFlow(EntityTestCase, unittest.TestCase):
    klass = YAFReverseFlow

    _full_dict = {
        'reverse_octet_total_count': 144,
        'reverse_packet_total_count': 100,
        'reverse_payload_entropy': 25,
        'reverse_flow_delta_milliseconds': 1356,
        'tcp_reverse_flow': TestYAFTCPFlow._full_dict,
        'reverse_vlan_id_mac_addr': TestAddress._full_dict,
        'reverse_passive_os_fingerprinting': {
            'description': u("The best platform"),
            'identifier': [
                u("value1")
            ]
        },
        'reverse_first_packet': u('00'),
        'reverse_n_bytes_payload': u('EC'),
    }


class TestYAFRecord(EntityTestCase, unittest.TestCase):
    klass = YAFRecord

    _full_dict = {
        'flow': TestYAFFlow._full_dict,
        'reverse_flow': TestYAFReverseFlow._full_dict,
    }


class TestIPFIXSetHeader(EntityTestCase, unittest.TestCase):
    klass = IPFIXSetHeader

    _full_dict = {
        'set_id': 35,
        'length': 100,
    }


class TestIPFIXDataRecord(EntityTestCase, unittest.TestCase):
    klass = IPFIXDataRecord

    _full_dict = {
        'field_value': [
            u('value1'),
            u('value2'),
        ]
    }


class TestIPFIXMessageHeader(EntityTestCase, unittest.TestCase):
    klass = IPFIXMessageHeader

    _full_dict = {
        'version': u('A0'),
        'byte_length': u('FEAC'),
        'export_timestamp': 1582060823,
        'sequence_number': 19382,
        'observation_domain_id': 245,
    }


class TestIPFIXTemplateRecordFieldSpecifiers(EntityTestCase, unittest.TestCase):
    klass = IPFIXTemplateRecordFieldSpecifiers

    _full_dict = {
        'enterprise_bit': True,
        'information_element_id': 'Something',
        'field_length': '128395',
        'enterprise_number': '1.3.6.1.4.1',
    }


class TestIPFIXTemplateRecordHeader(EntityTestCase, unittest.TestCase):
    klass = IPFIXTemplateRecordHeader

    _full_dict = {
        'template_id': 556,
        'field_count': 'FF452'
    }


class TestIPFIXOptionsTemplateRecordHeader(EntityTestCase, unittest.TestCase):
    klass = IPFIXOptionsTemplateRecordHeader

    _full_dict = {
        'template_id': 160,
        'field_count': 'BF45',
        'scope_field_count': 15,
    }


class TestIPFIXDataSet(EntityTestCase, unittest.TestCase):
    klass = IPFIXDataSet

    _full_dict = {
        'set_header': TestIPFIXSetHeader._full_dict,
        'data_record': [
            TestIPFIXDataRecord._full_dict
        ],
        'padding': u('0C'),
    }


class TestIPFIXOptionsTemplateRecord(EntityTestCase, unittest.TestCase):
    klass = IPFIXOptionsTemplateRecord

    _full_dict = {
        'options_template_record_header': TestIPFIXOptionsTemplateRecordHeader._full_dict,
        'field_specifier': [
            TestIPFIXTemplateRecordFieldSpecifiers._full_dict
        ]
    }


class TestIPFIXOptionsTemplateSet(EntityTestCase, unittest.TestCase):
    klass = IPFIXOptionsTemplateSet

    _full_dict = {
        'set_header': TestIPFIXSetHeader._full_dict,
        'options_template_record': [
            TestIPFIXOptionsTemplateRecord._full_dict
        ],
        'padding': u('C0')
    }


class TestIPFIXTemplateRecord(EntityTestCase, unittest.TestCase):
    klass = IPFIXTemplateRecord

    _full_dict = {
        'template_record_header': TestIPFIXTemplateRecordHeader._full_dict,
        'field_specifier': [
            TestIPFIXTemplateRecordFieldSpecifiers._full_dict
        ]
    }


class TestIPFIXTemplateSet(EntityTestCase, unittest.TestCase):
    klass = IPFIXTemplateSet

    _full_dict = {
        'set_header': TestIPFIXSetHeader._full_dict,
        'template_record': [
            TestIPFIXTemplateRecord._full_dict
        ],
        'padding': u('FE')
    }


class TestIPFIXSet(EntityTestCase, unittest.TestCase):
    klass = IPFIXSet

    _full_dict = {
        'template_set': TestIPFIXTemplateSet._full_dict,
        'options_template_set': TestIPFIXOptionsTemplateSet._full_dict,
        'data_set': TestIPFIXDataSet._full_dict,
    }


class TestIPFIXMessage(EntityTestCase, unittest.TestCase):
    klass = IPFIXMessage

    _full_dict = {
        'message_header': TestIPFIXMessageHeader._full_dict,
        'set': [
            TestIPFIXSet._full_dict
        ]
    }


class TestNetflowV5FlowRecord(EntityTestCase, unittest.TestCase):
    klass = NetflowV5FlowRecord

    _full_dict = {
        'nexthop_ipv4_addr': TestAddress._full_dict,
        'packet_count': 50,
        'byte_count': 123448,
        'sysuptime_start': 1582060823,
        'sysuptime_end': 1582060824,
        'padding1': u('0'),
        'tcp_flags': u('02'),
        'src_autonomous_system': 2,
        'dest_autonomous_system': 1,
        'src_ip_mask_bit_count': u('0'),
        'dest_ip_mask_bit_count': u('0'),
        'padding2': u('0'),
    }


class TestNetflowV5FlowHeader(EntityTestCase, unittest.TestCase):
    klass = NetflowV5FlowHeader

    _full_dict = {
        'version': u('05'),
        'count': 2,
        'sys_up_time': 1582060823,
        'unix_secs': 345,
        'unix_nsecs': 348,
        'flow_sequence': 55,
        'engine_type': u('Some Engine'),
        'engine_id': 4523,
        'sampling_interval': u('CE'),
    }


class TestNetflowV5Packet(EntityTestCase, unittest.TestCase):
    klass = NetflowV5Packet

    _full_dict = {
        'flow_header': TestNetflowV5FlowHeader._full_dict,
        'flow_record': [
            TestNetflowV5FlowRecord._full_dict
        ]
    }


class TestOptionCollectionElement(EntityTestCase, unittest.TestCase):
    klass = OptionCollectionElement

    _full_dict = {
        'option_record_field_value': [
            u('Some Value2')
        ]
    }


class TestFlowCollectionElement(EntityTestCase, unittest.TestCase):
    klass = FlowCollectionElement

    _full_dict = {
        'flow_record_field_value': [
            u('Some String')
        ]
    }


class TestFlowDataRecord(EntityTestCase, unittest.TestCase):
    klass = FlowDataRecord

    _full_dict = {
        'flow_record_collection_element': [
            TestFlowCollectionElement._full_dict
        ]
    }


class TestOptionsDataRecord(EntityTestCase, unittest.TestCase):
    klass = OptionsDataRecord

    _full_dict = {
        'scope_field_value': u('Some Value'),
        'option_record_collection_element': [
            TestOptionCollectionElement._full_dict
        ]
    }


class TestNetflowV9PacketHeader(EntityTestCase, unittest.TestCase):
    klass = NetflowV9PacketHeader

    _full_dict = {
        'version': u('09'),
        'record_count': 20,
        'sys_up_time': 1582060823,
        'unix_secs': 34,
        'sequence_number': 553242,
        'source_id': u('312E'),
    }


class TestNetflowV9DataRecord(EntityTestCase, unittest.TestCase):
    klass = NetflowV9DataRecord

    _full_dict = {
        'flow_data_record': [
            TestFlowDataRecord._full_dict
        ],
        'options_data_record': [
            TestOptionsDataRecord._full_dict
        ],
    }


class TestNetflowV9DataFlowSet(EntityTestCase, unittest.TestCase):
    klass = NetflowV9DataFlowSet

    _full_dict = {
        'flow_set_id_template_id': 2,
        'length': 10,
        'data_record': [
            TestNetflowV9DataRecord._full_dict
        ],
        'padding': u('DE'),
    }


class TestNetflowV9TemplateRecord(EntityTestCase, unittest.TestCase):
    klass = NetflowV9TemplateRecord

    _full_dict = {
        'template_id': 2345,
        'field_count': 110,
        'field_type': u(NetflowV9Field.TERM_IN_BYTES),
        'field_length': u('FF'),
    }


class TestNetflowV9TemplateFlowSet(EntityTestCase, unittest.TestCase):
    klass = NetflowV9TemplateFlowSet

    _full_dict = {
        'flow_set_id': u('AA'),
        'length': 100,
        'template_record': [
            TestNetflowV9TemplateRecord._full_dict
        ],
    }


class TestNetflowV9OptionsTemplateRecord(EntityTestCase, unittest.TestCase):
    klass = NetflowV9OptionsTemplateRecord

    _full_dict = {
        'template_id': 341,
        'option_scope_length': u('A4'),
        'option_length': u('2'),
        'scope_field_type': u('Scope Type'),
        'scope_field_length': u('E0'),
        'option_field_type': u('IN_BYTES(1)'),
        'option_field_length': u('B0'),
    }


class TestNetflowV9OptionsTemplateFlowSet(EntityTestCase, unittest.TestCase):
    klass = NetflowV9OptionsTemplateFlowSet

    _full_dict = {
        'flow_set_id': u('01'),
        'length': 10,
        'options_template_record': [
            TestNetflowV9OptionsTemplateRecord._full_dict
        ],
        'padding': u('AB'),
    }


class TestNetflowV9FlowSet(EntityTestCase, unittest.TestCase):
    klass = NetflowV9FlowSet

    _full_dict = {
        'template_flow_set': TestNetflowV9TemplateFlowSet._full_dict,
        'options_template_flow_set': TestNetflowV9OptionsTemplateFlowSet._full_dict,
        'data_flow_set': TestNetflowV9DataFlowSet._full_dict,
    }


class TestNetflowV9ExportPacket(EntityTestCase, unittest.TestCase):
    klass = NetflowV9ExportPacket

    _full_dict = {
        'packet_header': TestNetflowV9PacketHeader._full_dict,
        'flow_set': [
            TestNetflowV9FlowSet._full_dict
        ]
    }


class TestSiLKSensorInfo(EntityTestCase, unittest.TestCase):
    klass = SiLKSensorInfo

    _full_dict = {
        'sensor_id': u('2349'),
        'class': u(SiLKSensorClass.TERM_ALL),
        'type': u(SiLKSensorDirection.TERM_IN),
    }


class TestSiLKRecord(EntityTestCase, unittest.TestCase):
    klass = SiLKRecord

    _full_dict = {
        'packet_count': 55,
        'byte_count': 12800,
        'tcp_flags': u('B9'),
        'start_time': 1582060823,
        'duration': 100,
        'end_time': 1582060923,
        'sensor_info': TestSiLKSensorInfo._full_dict,
        'icmp_type': 6,
        'icmp_code': 2,
        'router_next_hop_ip': TestAddress._full_dict,
        'initial_tcp_flags': TestTCPFlags._full_dict,
        'session_tcp_flags': u('3'),
        'flow_attributes': u(SiLKFlowAttributes.TERM_F),
        'flow_application': u('My Flow Application'),
        'src_ip_type': u(SiLKAddress.TERM_INTERNAL),
        'dest_ip_type': u(SiLKAddress.TERM_EXTERNAL),
        'src_country_code': u('US'),
        'dest_country_code': u('US'),
        'src_mapname': u('some value1'),
        'dest_mapname': u('some value2'),
    }


class TestUnidirectionalRecord(EntityTestCase, unittest.TestCase):
    klass = UnidirectionalRecord

    _full_dict = {
        'ipfix_message': TestIPFIXMessage._full_dict,
        'netflowv9_export_packet': TestNetflowV9ExportPacket._full_dict,
        'netflowv5_packet': TestNetflowV5Packet._full_dict,
        'silk_record': TestSiLKRecord._full_dict,
    }


class TestBidirectionalRecord(EntityTestCase, unittest.TestCase):
    klass = BidirectionalRecord

    _full_dict = {
        'yaf_record': TestYAFRecord._full_dict
    }


class TestNetworkFlow(ObjectTestCase, unittest.TestCase):
    object_type = "NetworkFlowObjectType"
    klass = NetworkFlow

    _full_dict = {
        'network_flow_label': TestNetworkFlowLabel._full_dict,
        'unidirectional_flow_record': TestUnidirectionalRecord._full_dict,
        'bidirectional_flow_record': TestBidirectionalRecord._full_dict,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.gui_dialogbox_object import GUIDialogbox
from cybox.test.objects import ObjectTestCase


class TestGUIDialogbox(ObjectTestCase, unittest.TestCase):
    object_type = "GUIDialogboxObjectType"
    klass = GUIDialogbox

    _full_dict = {
        'box_caption': u('Sample caption'),
        'box_text': u('Sample text'),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import cybox.bindings.cybox_common as common_binding
from cybox.common import BaseProperty


class Cipher(BaseProperty):
    _binding = common_binding
    _binding_class = common_binding.CipherType
    _namespace = 'http://cybox.mitre.org/common-2'

    TERM_3DES = "3DES"
    TERM_AES = "AES"
    TERM_BLOWFISH = "Blowfish"
    TERM_CAST128 = "CAST-128"
    TERM_CAST256 = "CAST-256"
    TERM_DES = "DES"
    TERM_IDEA = "IDEA"
    TERM_RIJNDAEL = "Rijndael"
    TERM_RC5 = "RC5"
    TERM_SKIPJACK = "Skipjack"



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.win_user_account_object import WinGroup, WinGroupList, WinPrivilege, WinPrivilegeList, WinUser
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase


class TestWinGroup(EntityTestCase, unittest.TestCase):
    klass = WinGroup

    _full_dict = {
        'name': u("LocalAdministrators"),
        'xsi:type': 'WindowsGroupType',
    }


class TestWinGroupList(EntityTestCase, unittest.TestCase):
    klass = WinGroupList

    _full_dict = [
        TestWinGroup._full_dict,
        TestWinGroup._full_dict,
    ]


class TestWinPrivilege(EntityTestCase, unittest.TestCase):
    klass = WinPrivilege

    _full_dict = {
        'user_right': u("SeDebugPrivilege"),
        'xsi:type': 'WindowsPrivilegeType',
    }


class TestWinPrivilegeList(EntityTestCase, unittest.TestCase):
    klass = WinPrivilegeList

    _full_dict = [
        TestWinPrivilege._full_dict,
        TestWinPrivilege._full_dict,
    ]


class TestWinUser(ObjectTestCase, unittest.TestCase):
    object_type = "WindowsUserAccountObjectType"
    klass = WinUser

    _full_dict = {
        # Account-specific fields
        'disabled': False,
        'domain': u('ADMIN'),
        # UserAccount-specific fields
        'password_required': True,
        'full_name': u("Steve Ballmer"),
        'group_list': TestWinGroupList._full_dict,
        'home_directory': u("C:\\\\Users\\\\ballmer\\\\"),
        'last_login': "2011-05-12T07:14:01+07:00",
        'privilege_list': TestWinPrivilegeList._full_dict,
        'username': u("ballmer"),
        'user_password_age': u("P180D"),
        # WinUser-specific fields
        'security_id': u("S-1-5-21-3623811015-3361044348-30300820-1013"),
        'security_type': u("SidTypeUser"),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.


class UnknownObjectType(Exception):
    pass


def get_class_for_object_type(object_type):
    return _OBJ_META.get_class_for_object_type(object_type)


class _ObjectType(object):

    def __init__(self, name, api_class, binding, namespace, dependencies):
        """Create a new namespace.

        Arguments (all strings)
        - name: the name of the Object
        - api_class: The fully qualified name of the class that implements
          the Object
        - binding: the name of the binding containing the Object
        - namespace: the namespace where the Object is defined
        - dependencies: a list of strings, where each string is another
          ObjectType
        """
        self.name = name
        self.api_class = api_class
        self.binding = binding
        self.namespace = namespace
        self.dependencies = dependencies


class _ObjectMetadata(object):
    """Metadata about CybOX objects."""

    def __init__(self, object_list):
        self._obj_dict = {}

        for obj in object_list:
            o = _ObjectType(*obj)
            self.add_object(o)

    def add_object(self, object_type):
        # TODO: are there other ways we want to look up this data?
        self._obj_dict[object_type.name] = object_type

    def lookup_object(self, object_name):
        return self._obj_dict.get(object_name)

    def get_class_for_object_type(self, object_type):
        """Gets the class where a given XML Type can be parsed.

        Each ObjectType instance should define a member api_class, which
        consists of a fully-qualified name of a class (including the module it
        is defined in).

        Arguments:
        - object_type: a string

        Raises:
        - UnknownObjectType, if object_type has not been defined in obj_list.
        - ImportError, if the specified module is not available.
        - AttributeError, if the module does not contain the given class.
        """
        otype = self.lookup_object(object_type)
        if not otype:
            err = "%s is not a known ObjectType" % object_type
            raise UnknownObjectType(err)

        full_class_name = otype.api_class
        if not full_class_name:
            err = "%s does not have a specified API class" % object_type
            raise UnknownObjectType(err)

        module = ".".join(full_class_name.split('.')[:-1])
        class_name = full_class_name.split('.')[-1]

        # May raise ImportError
        mod = __import__(module, fromlist=[class_name])

        # May raise AttributeError
        return getattr(mod, class_name)


# A list of (object_name, api_class, binding, namespace, dependencies) tuples
# This is loaded by the ObjectMetadata class and should not be accessed
# directly.
OBJ_LIST = [
    ('AccountObjectType', 'cybox.objects.account_object.Account', 'account_object', 'http://cybox.mitre.org/objects#AccountObject-2', []),
    ('AddressObjectType', 'cybox.objects.address_object.Address', 'address_object', 'http://cybox.mitre.org/objects#AddressObject-2', []),
    ('APIObjectType', 'cybox.objects.api_object.API', 'api_object', 'http://cybox.mitre.org/objects#APIObject-2', []),
    ('ArchiveFileObjectType', 'cybox.objects.archive_file_object.ArchiveFile', 'archive_file_object', 'http://cybox.mitre.org/objects#ArchiveFileObject-1', ['FileObjectType']),
    ('ArtifactObjectType', 'cybox.objects.artifact_object.Artifact', 'artifact_object', 'http://cybox.mitre.org/objects#ArtifactObject-2', []),
    ('ARPCacheObjectType', 'cybox.objects.arp_cache_object.ARPCache', 'arp_cache_object', 'http://cybox.mitre.org/objects#ARPCacheObject-1', []),
    ('ASObjectType', 'cybox.objects.as_object.AS', 'as_object', 'http://cybox.mitre.org/objects#ASObject-1', []),
    ('CodeObjectType', 'cybox.objects.code_object.Code', 'code_object', 'http://cybox.mitre.org/objects#CodeObject-2', []),
    ('CustomObjectType', 'cybox.objects.custom_object.Custom', 'custom_object', 'http://cybox.mitre.org/objects#CustomObject-1', []),
    ('DeviceObjectType', 'cybox.objects.device_object.Device', 'device_object', 'http://cybox.mitre.org/objects#DeviceObject-2', []),
    ('DiskObjectType', 'cybox.objects.disk_object.Disk', 'disk_object', 'http://cybox.mitre.org/objects#DiskObject-2', ['DiskPartitionObjectType']),
    ('DiskPartitionObjectType', 'cybox.objects.disk_partition_object.DiskPartition', 'disk_partition_object', 'http://cybox.mitre.org/objects#DiskPartitionObject-2', []),
    ('DNSCacheObjectType', 'cybox.objects.dns_cache_object.DNSCache', 'dns_cache_object', 'http://cybox.mitre.org/objects#DNSCacheObject-2', ['DNSRecordObjectType', 'AddressObjectType', 'URIObjectType']),
    ('DNSQueryObjectType', 'cybox.objects.dns_query_object.DNSQuery', 'dns_query_object', 'http://cybox.mitre.org/objects#DNSQueryObject-2', ['DNSRecordObjectType', 'URIObjectType', 'AddressObjectType']),
    ('DNSRecordObjectType', 'cybox.objects.dns_record_object.DNSRecord', 'dns_record_object', 'http://cybox.mitre.org/objects#DNSRecordObject-2', ['URIObjectType', 'AddressObjectType']),
    ('DomainNameObjectType', 'cybox.objects.domain_name_object.DomainName', 'domain_name_object', 'http://cybox.mitre.org/objects#DomainNameObject-1', []),
    ('EmailMessageObjectType', 'cybox.objects.email_message_object.EmailMessage', 'email_message_object', 'http://cybox.mitre.org/objects#EmailMessageObject-2', ['FileObjectType', 'AddressObjectType', 'URIObjectType']),
    ('FileObjectType', 'cybox.objects.file_object.File', 'file_object', 'http://cybox.mitre.org/objects#FileObject-2', []),
    ('GUIDialogboxObjectType', 'cybox.objects.gui_dialogbox_object.GUIDialogbox', 'gui_dialogbox_object', 'http://cybox.mitre.org/objects#GUIDialogboxObject-2', ['GUIObjectType']),
    ('GUIObjectType', 'cybox.objects.gui_object.GUI', 'gui_object', 'http://cybox.mitre.org/objects#GUIObject-2', []),
    ('GUIWindowObjectType', 'cybox.objects.gui_window_object.GUIWindow', 'gui_window_object', 'http://cybox.mitre.org/objects#GUIWindowObject-2', ['GUIObjectType']),
    ('HostnameObjectType', 'cybox.objects.hostname_object.Hostname', 'hostname_object', 'http://cybox.mitre.org/objects#HostnameObject-1', []),
    ('HTTPSessionObjectType', 'cybox.objects.http_session_object.HTTPSession', 'http_session_object', 'http://cybox.mitre.org/objects#HTTPSessionObject-2', ['AddressObjectType', 'PortObjectType', 'URIObjectType']),
    ('ImageFileObjectType', 'cybox.objects.image_file_object.ImageFile', 'image_file_object', 'http://cybox.mitre.org/objects#ImageFileObject-1', ['FileObjectType']),
    ('LibraryObjectType', 'cybox.objects.library_object.Library', 'library_object', 'http://cybox.mitre.org/objects#LibraryObject-2', []),
    ('LinkObjectType', 'cybox.objects.link_object.Link', 'link_object', 'http://cybox.mitre.org/objects#LinkObject-1', ['URIObjectType']),
    ('LinuxPackageObjectType', 'cybox.objects.linux_package_object.LinuxPackage', 'linux_package_object', 'http://cybox.mitre.org/objects#LinuxPackageObject-2', []),
    ('MemoryObjectType', 'cybox.objects.memory_object.Memory', 'memory_object', 'http://cybox.mitre.org/objects#MemoryObject-2', []),
    ('MutexObjectType', 'cybox.objects.mutex_object.Mutex', 'mutex_object', 'http://cybox.mitre.org/objects#MutexObject-2', []),
    ('NetRouteObjectType', 'cybox.objects.network_route_object.NetRoute', 'network_route_object', 'http://cybox.mitre.org/objects#NetworkRouteObject-2', ['NetworkRouteEntryObjectType', 'AddressObjectType']),
    ('NetworkConnectionObjectType', 'cybox.objects.network_connection_object.NetworkConnection', 'network_connection_object', 'http://cybox.mitre.org/objects#NetworkConnectionObject-2', ['SocketAddressObjectType', 'HTTPSessionObjectType', 'DNSQueryObjectType', 'DNSRecordObjectType', 'URIObjectType']),
    ('NetworkFlowObjectType', 'cybox.objects.network_flow_object.NetworkFlow', 'network_flow_object', 'http://cybox.mitre.org/objects#NetworkFlowObject-2', ['NetworkPacketType', 'AddressObjectType', 'SocketAddressObjectType']),
    ('NetworkPacketObjectType', 'cybox.objects.network_packet_object.NetworkPacket', 'network_packet_object', 'http://cybox.mitre.org/objects#PacketObject-2', ['AddressObjectType', 'PortObjectType']),
    ('NetworkRouteEntryObjectType', 'cybox.objects.network_route_entry_object.NetworkRouteEntry', 'network_route_entry_object', 'http://cybox.mitre.org/objects#NetworkRouteEntryObject-2', ['AddressObjectType']),
    ('NetworkSocketObjectType', 'cybox.objects.network_socket_object.NetworkSocket', 'network_socket_object', 'http://cybox.mitre.org/objects#NetworkSocketObject-2', ['SocketAddressObjectType']),
    ('NetworkSubnetObjectType', 'cybox.objects.network_subnet_object.NetworkSubnet', 'network_subnet_object', 'http://cybox.mitre.org/objects#NetworkSubnetObject-2', ['NetworkRouteEntryObjectType', 'AddressObjectType']),
    ('PDFFileObjectType', 'cybox.objects.pdf_file_object.PDFFile', 'pdf_file_object', 'http://cybox.mitre.org/objects#PDFFileObject-1', ['FileObjectType']),
    ('PipeObjectType', 'cybox.objects.pipe_object.Pipe', 'pipe_object', 'http://cybox.mitre.org/objects#PipeObject-2', []),
    ('PortObjectType', 'cybox.objects.port_object.Port', 'port_object', 'http://cybox.mitre.org/objects#PortObject-2', []),
    ('ProcessObjectType', 'cybox.objects.process_object.Process', 'process_object', 'http://cybox.mitre.org/objects#ProcessObject-2', ['NetworkConnectionObjectType', 'PortObjectType']),
    ('ProductObjectType', 'cybox.objects.product_object.Product', 'product_object', 'http://cybox.mitre.org/objects#ProductObject-2', []),
    ('SemaphoreObjectType', 'cybox.objects.semaphore_object.Semaphore', 'semaphore_object', 'http://cybox.mitre.org/objects#SemaphoreObject-2', []),
    ('SMSMessageObjectType', 'cybox.objects.sms_message_object.SMSMessage', 'sms_message_object', 'http://cybox.mitre.org/objects#SMSMessageObject-1', []),
    ('SocketAddressObjectType', 'cybox.objects.socket_address_object.SocketAddress', 'socket_address_object', 'http://cybox.mitre.org/objects#SocketAddressObject-1', ['AddressObjectType', 'PortObjectType']),
    ('SystemObjectType', 'cybox.objects.system_object.System', 'system_object', 'http://cybox.mitre.org/objects#SystemObject-2', ['AddressObjectType']),
    ('UnixFileObjectType', 'cybox.objects.unix_file_object.UnixFile', 'unix_file_object', 'http://cybox.mitre.org/objects#UnixFileObject-2', ['FileObjectType']),
    ('UnixNetworkRouteEntryObjectType', 'cybox.objects.unix_network_route_entry_object.UnixNetworkRouteEntry', 'unix_network_route_entry_object', 'http://cybox.mitre.org/objects#UnixNetworkRouteEntryObject-2', ['NetworkRouteEntryObjectType', 'AddressObjectType']),
    ('UnixPipeObjectType', 'cybox.objects.unix_pipe_object.UnixPipe', 'unix_pipe_object', 'http://cybox.mitre.org/objects#UnixPipeObject-2', ['PipeObjectType']),
    ('UnixProcessObjectType', 'cybox.objects.unix_process_object.UnixProcess', 'unix_process_object', 'http://cybox.mitre.org/objects#UnixProcessObject-2', ['ProcessObjectType', 'AddressObjectType', 'PortObjectType']),
    ('UnixUserAccountObjectType', 'cybox.objects.unix_user_account_object.UnixUserAccount', 'unix_user_account_object', 'http://cybox.mitre.org/objects#UnixUserAccountObject-2', ['UserAccountObjectType', 'AccountObjectType']),
    ('UnixVolumeObjectType', 'cybox.objects.unix_volume_object.UnixVolume', 'unix_volume_object', 'http://cybox.mitre.org/objects#UnixVolumeObject-2', ['VolumeObjectType']),
    ('URIObjectType', 'cybox.objects.uri_object.URI', 'uri_object', 'http://cybox.mitre.org/objects#URIObject-2', []),
    ('URLHistoryObjectType', 'cybox.objects.url_history_object.URLHistory', 'url_history_object', 'http://cybox.mitre.org/objects#URLHistoryObject-1', ['URIObjectType', 'HostnameObjectType']),
    ('UserAccountObjectType', 'cybox.objects.user_account_object.UserAccount', 'user_account_object', 'http://cybox.mitre.org/objects#UserAccountObject-2', ['AccountObjectType']),
    ('UserSessionObjectType', 'cybox.objects.user_session_object.UserSession', 'user_session_object', 'http://cybox.mitre.org/objects#UserSessionObject-2', []),
    ('VolumeObjectType', 'cybox.objects.volume_object.Volume', 'volume_object', 'http://cybox.mitre.org/objects#VolumeObject-2', []),
    ('WhoisObjectType', 'cybox.objects.whois_object.WhoisEntry', 'whois_object', 'http://cybox.mitre.org/objects#WhoisObject-2', ['URIObjectType', 'AddressObjectType']),
    ('WindowsComputerAccountObjectType', 'cybox.objects.win_computer_account_object.WinComputerAccount', 'win_computer_account_object', 'http://cybox.mitre.org/objects#WinComputerAccountObject-2', ['AccountObjectType', 'PortObjectType']),
    ('WindowsCriticalSectionObjectType', 'cybox.objects.win_critical_section_object.WinCriticalSection', 'win_critical_section_object', 'http://cybox.mitre.org/objects#WinCriticalSectionObject-2', []),
    ('WindowsDriverObjectType', 'cybox.objects.win_driver_object.WinDriver', 'win_driver_object', 'http://cybox.mitre.org/objects#WinDriverObject-3', []),
    ('WindowsEventLogObjectType', 'cybox.objects.win_event_log_object.WinEventLog', 'win_event_log_object', 'http://cybox.mitre.org/objects#WinEventLogObject-2', []),
    ('WindowsEventObjectType', 'cybox.objects.win_event_object.WinEvent', 'win_event_object', 'http://cybox.mitre.org/objects#WinEventObject-2', ['WindowsHandleObjectType']),
    ('WindowsExecutableFileObjectType', 'cybox.objects.win_executable_file_object.WinExecutableFile', 'win_executable_file_object', 'http://cybox.mitre.org/objects#WinExecutableFileObject-2', ['WindowsFileObjectType', 'FileObjectType', 'WinComputerAccountObjectType', 'AccountObjectType', 'PortObjectType']),
    ('WindowsFileObjectType', 'cybox.objects.win_file_object.WinFile', 'win_file_object', 'http://cybox.mitre.org/objects#WinFileObject-2', ['FileObjectType', 'WinComputerAccountObjectType', 'AccountObjectType', 'PortObjectType']),
    ('WindowsFilemappingObjectType', 'cybox.objects.win_filemapping_object.WinFilemapping', 'win_filemapping_object', 'http://cybox.mitre.org/objects#WinFilemappingObject-1', ['WindowsHandleObjectType']),
    ('WindowsHandleObjectType', 'cybox.objects.win_handle_object.WinHandle', 'win_handle_object', 'http://cybox.mitre.org/objects#WinHandleObject-2', []),
    ('WindowsHookObjectType', 'cybox.objects.win_hook_object.WinHook', 'windows_hook_object', 'http://cybox.mitre.org/objects#WinHookObject-1', ['WindowsHandleObjectType','LibraryObjectType']),
    ('WindowsKernelHookObjectType', 'cybox.objects.win_kernel_hook_object.WinKernelHook', 'win_kernel_hook_object', 'http://cybox.mitre.org/objects#WinKernelHookObject-2', []),
    ('WindowsKernelObjectType', 'cybox.objects.win_kernel_object.WinKernel', 'win_kernel_object', 'http://cybox.mitre.org/objects#WinKernelObject-2', []),
    ('WindowsMailslotObjectType', 'cybox.objects.win_mailslot_object.WinMailslot', 'win_mailslot_object', 'http://cybox.mitre.org/objects#WinMailslotObject-2', ['WindowsHandleObjectType']),
    ('WindowsMemoryPageRegionObjectType', 'cybox.objects.win_memory_page_region_object.WinMemoryPageRegion', 'win_memory_page_region_object', 'http://cybox.mitre.org/objects#WinMemoryPageRegionObject-2', ['MemoryObjectType']),
    ('WindowsMutexObjectType', 'cybox.objects.win_mutex_object.WinMutex', 'win_mutex_object', 'http://cybox.mitre.org/objects#WinMutexObject-2', ['WindowsHandleObjectType', 'MutexObjectType']),
    ('WindowsNetworkRouteEntryObjectType', 'cybox.objects.win_network_route_entry_object.WinNetworkRouteEntry', 'win_network_route_entry_object', 'http://cybox.mitre.org/objects#WinNetworkRouteEntryObject-2', ['NetworkRouteEntryObjectType', 'AddressObjectType']),
    ('WindowsNetworkShareObjectType', 'cybox.objects.win_network_share_object.WinNetworkShare', 'win_network_share_object', 'http://cybox.mitre.org/objects#WinNetworkShareObject-2', []),
    ('WindowsPipeObjectType', 'cybox.objects.win_pipe_object.WinPipe', 'win_pipe_object', 'http://cybox.mitre.org/objects#WinPipeObject-2', ['PipeObjectType']),
    ('WindowsPrefetchObjectType', 'cybox.objects.win_prefetch_object.WinPrefetch', 'win_prefetch_object', 'http://cybox.mitre.org/objects#WinPrefetchObject-2', ['WindowsVolumeObjectType', 'VolumeObjectType', 'DeviceObjectType']),
    ('WindowsProcessObjectType', 'cybox.objects.win_process_object.WinProcess', 'win_process_object', 'http://cybox.mitre.org/objects#WinProcessObject-2', ['ProcessObjectType', 'WindowsHandleObjectType', 'MemoryObjectType', 'AddressObjectType', 'PortObjectType']),
    ('WindowsRegistryKeyObjectType', 'cybox.objects.win_registry_key_object.WinRegistryKey', 'win_registry_key_object', 'http://cybox.mitre.org/objects#WinRegistryKeyObject-2', ['WindowsHandleObjectType']),
    ('WindowsSemaphoreObjectType', 'cybox.objects.win_semaphore_object.WinSemaphore', 'win_semaphore_object', 'http://cybox.mitre.org/objects#WinSemaphoreObject-2', ['WindowsHandleObjectType', 'SemaphoreObjectType']),
    ('WindowsServiceObjectType', 'cybox.objects.win_service_object.WinService', 'win_service_object', 'http://cybox.mitre.org/objects#WinServiceObject-2', ['WindowsProcessObjectType', 'WindowsHandleObjectType', 'MemoryObjectType', 'AddressObjectType', 'PortObjectType']),
    ('WindowsSystemObjectType', 'cybox.objects.win_system_object.WinSystem', 'win_system_object', 'http://cybox.mitre.org/objects#WinSystemObject-2', ['WindowsHandleObjectType', 'SystemObjectType', 'AddressObjectType']),
    ('WindowsSystemRestoreObjectType', 'cybox.objects.win_system_restore_object.WinSystemRestore', 'win_system_restore_object', 'http://cybox.mitre.org/objects#WinSystemRestoreObject-2', []),
    ('WindowsTaskObjectType', 'cybox.objects.win_task_object.WinTask', 'win_task_object', 'http://cybox.mitre.org/objects#WinTaskObject-2', ['EmailMessageObjectType', 'FileObjectType', 'AddressObjectType', 'URIObjectType']),
    ('WindowsThreadObjectType', 'cybox.objects.win_thread_object.WinThread', 'win_thread_object', 'http://cybox.mitre.org/objects#WinThreadObject-2', ['WindowsHandleObjectType']),
    ('WindowsUserAccountObjectType', 'cybox.objects.win_user_account_object.WinUser', 'win_user_account_object', 'http://cybox.mitre.org/objects#WinUserAccountObject-2', ['UserAccountObjectType', 'AccountObjectType']),
    ('WindowsVolumeObjectType', 'cybox.objects.win_volume_object.WinVolume', 'win_volume_object', 'http://cybox.mitre.org/objects#WinVolumeObject-2', ['VolumeObjectType']),
    ('WindowsWaitableTimerObjectType', 'cybox.objects.win_waitable_timer_object.WinWaitableTimer', 'win_waitable_timer_object', 'http://cybox.mitre.org/objects#WinWaitableTimerObject-2', ['WindowsHandleObjectType']),
    ('X509CertificateObjectType', 'cybox.objects.x509_certificate_object.X509Certificate', 'x509_certificate_object', 'http://cybox.mitre.org/objects#X509CertificateObject-2', []),
]


_OBJ_META = _ObjectMetadata(OBJ_LIST)



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.common import Hash, ToolInformation, ToolInformationList
import cybox.test
from cybox.test import EntityTestCase
from cybox.test.common.hash_test import EMPTY_MD5


class TestToolInformation(EntityTestCase, unittest.TestCase):
    klass = ToolInformation

    _full_dict = {
        'id': "example:Tool-A1",
        # 'idref': "example:Tool-A1-ref",  # CAnnot set both an id and idref
        'name': "AwesomeTool(tm)",
        'type': [
            {
                'value': u('NIDS'),
                'xsi:type': 'cyboxVocabs:ToolTypeVocab-1.1'
            },
            {
                'value': u('HIPS'),
                'xsi:type': 'cyboxVocabs:ToolTypeVocab-1.1'
            }
        ],
        'description': {
            'structuring_format': 'HTML',
            'value': '<p>An awesome tool!</p>'
        },
        'vendor': "Awesome Co.",
        'version': "1.0.0",
        'service_pack': 'N/A',
        'references': {
            'reference': [
                {
                    'reference_type': 'Other',
                    'value': 'some-ref-value'
                }
            ],
        },
        'tool_hashes': [
            {
                'simple_hash_value': EMPTY_MD5,
                'type': Hash.TYPE_MD5
            }
        ],
        'metadata': [
            {
                'type': 'uri',
                'value': 'tool metadata'
            }
        ]
    }


class TestHashList(unittest.TestCase):

    def test_round_trip(self):
        toolinfolist_list = [
                {'id': "example:Tool-A1", 'name': "Tool 1"},
                {'id': "example:Tool-A2", 'name': "Tool 2"},
            ]
        toolinfolist_list2 = cybox.test.round_trip_list(ToolInformationList,
                                                       toolinfolist_list)
        self.assertEqual(toolinfolist_list, toolinfolist_list2)


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox
import cybox.bindings.cybox_common as common_binding


class LocationFactory(entities.EntityFactory):
    @classmethod
    def entity_class(cls, key):
        return cybox.lookup_extension(key, default=Location)


class Location(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.LocationType
    _namespace = 'http://cybox.mitre.org/common-2'
    _XSI_TYPE = None  # overridden by subclasses

    id_ = fields.IdrefField("id")
    idref = fields.IdrefField("idref")
    name = fields.TypedField("Name")

    def to_dict(self):
        d = super(Location, self).to_dict()

        if self._XSI_TYPE:
            d["xsi:type"] = self._XSI_TYPE

        return d

    @staticmethod
    def lookup_class(xsi_type):
        return cybox.lookup_extension(xsi_type, default=Location)



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox.bindings.win_volume_object as win_volume_binding
from cybox.objects.volume_object import Volume
from cybox.common import BaseProperty, String


class WindowsDrive(BaseProperty):
    _binding = win_volume_binding
    _binding_class = win_volume_binding.WindowsDriveType
    _namespace = "http://cybox.mitre.org/objects#WinVolumeObject-2"

    TYPE_DRIVE_UNKNOWN = "DRIVE_UNKNOWN"
    TYPE_DRIVE_NO_ROOT_DIR = "DRIVE_NO_ROOT_DIR"
    TYPE_DRIVE_REMOVABLE = "DRIVE_REMOVABLE"
    TYPE_DRIVE_FIXED = "DRIVE_FIXED"
    TYPE_DRIVE_REMOTE = "DRIVE_REMOTE"
    TYPE_DRIVE_CDROM = "DRIVE_CDROM"
    TYPE_DRIVE_RAMDISK = "DRIVE_RAMDISK"


class WindowsVolumeAttribute(BaseProperty):
    _binding = win_volume_binding
    _binding_class = win_volume_binding.WindowsVolumeAttributeType
    _namespace = "http://cybox.mitre.org/objects#WinVolumeObject-2"

    TYPE_READ_ONLY = "ReadOnly"
    TYPE_HIDDEN = "Hidden"
    TYPE_NO_DEFAULT_DRIVE_LETTER = "NoDefaultDriveLetter"
    TYPE_SHADOW_COPY = "ShadowCopy"


class WindowsVolumeAttributesList(entities.EntityList):
    _binding = win_volume_binding
    _binding_class = win_volume_binding.WindowsVolumeAttributesListType
    _namespace = "http://cybox.mitre.org/objects#WinVolumeObject-2"

    attribute = fields.TypedField("Attribute", WindowsVolumeAttribute, multiple=True)


class WinVolume(Volume):
    _binding = win_volume_binding
    _binding_class = win_volume_binding.WindowsVolumeObjectType
    _namespace = "http://cybox.mitre.org/objects#WinVolumeObject-2"
    _XSI_NS = "WinVolumeObj"
    _XSI_TYPE = "WindowsVolumeObjectType"

    attributes_list = fields.TypedField("Attributes_List", WindowsVolumeAttributesList)
    drive_letter = fields.TypedField("Drive_Letter", String)
    drive_type = fields.TypedField("Drive_Type", WindowsDrive)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from cybox.objects.user_session_object import UserSession
from cybox.test.objects import ObjectTestCase


class TestUserSession(ObjectTestCase, unittest.TestCase):
    object_type = "UserSessionObjectType"
    klass = UserSession

    _full_dict = {
        'effective_group': 'dev',
        'effective_group_id': '500',
        'effective_user': 'user-1',
        'effective_user_id': '25',
        'login_time': "2001-01-01T06:56:50+04:00",
        'logout_time': "2001-01-02T06:56:50+04:00",
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.process_object import (ArgumentList, ChildPIDList,
                                          ImageInfo, NetworkConnectionList,
                                          PortList, Process)
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase
from cybox.test.objects.network_connection_test import TestNetworkConnection
from cybox.test.objects.port_test import TestPort


class TestChildPIDList(EntityTestCase, unittest.TestCase):
    klass = ChildPIDList

    _full_dict = [
        22500,
        915,
    ]


class TestPortList(EntityTestCase, unittest.TestCase):
    klass = PortList

    _full_dict = [
        TestPort._full_dict,
        TestPort._full_dict,
    ]


class TestNetworkConnectionList(EntityTestCase, unittest.TestCase):
    klass = NetworkConnectionList

    _full_dict = [
        TestNetworkConnection._full_dict,
        TestNetworkConnection._full_dict,
    ]


class TestArgumentList(EntityTestCase, unittest.TestCase):
    klass = ArgumentList

    _full_dict = [
        u('-p'),
        u('-d')
    ]


class TestImageInfo(EntityTestCase, unittest.TestCase):
    klass = ImageInfo

    _full_dict = {
        'file_name': 'testproc.bin',
        'command_line': 'testproc.bin -p -d',
        'current_directory': '/test',
        'path': '/home/some_path',
    }


class TestProcess(ObjectTestCase, unittest.TestCase):
    object_type = "ProcessObjectType"
    klass = Process

    _full_dict = {
        'pid': 512,
        'name': u('testproc'),
        'creation_time': '2001-01-01T06:56:50+04:00',
        'parent_pid': 1024,
        'child_pid_list': TestChildPIDList._full_dict,
        'image_info': TestImageInfo._full_dict,
        'argument_list': TestArgumentList._full_dict,
        'environment_variable_list': [
            {'name': 'TEMP', 'value': 'C:/TEMP'},
        ],
        'kernel_time': u('293457969'),
        'port_list': TestPortList._full_dict,
        'network_connection_list': TestNetworkConnectionList._full_dict,
        'start_time': '2001-01-01T06:56:50+04:00',
        'username': u('jondoe'),
        'user_time': u('120'),
        # 'extracted_features': '',
        'is_hidden': True,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import fields

import cybox.bindings.unix_user_account_object as unix_user_account_binding
from cybox.common import String, NonNegativeInteger, UnsignedInteger
from cybox.objects.user_account_object import (Group, GroupList, Privilege,
                                               PrivilegeList, UserAccount)


class UnixGroup(Group):
    _binding = unix_user_account_binding
    _binding_class = unix_user_account_binding.UnixGroupType
    _namespace = 'http://cybox.mitre.org/objects#UnixUserAccountObject-2'
    _XSI_TYPE = "UnixGroupType"

    group_id = fields.TypedField("Group_ID", NonNegativeInteger)


class UnixGroupList(GroupList):
    group = fields.TypedField("Group", UnixGroup, multiple=True)


class UnixPrivilege(Privilege):
    _binding = unix_user_account_binding
    _binding_class = unix_user_account_binding.UnixPrivilegeType
    _namespace = 'http://cybox.mitre.org/objects#UnixUserAccountObject-2'
    _XSI_TYPE = "UnixPrivilegeType"

    permissions_mask = fields.TypedField("Permissions_Mask", String)


class UnixPrivilegeList(PrivilegeList):
    privilege = fields.TypedField("Privilege", UnixPrivilege, multiple=True)


class UnixUserAccount(UserAccount):
    _binding = unix_user_account_binding
    _binding_class = unix_user_account_binding.UnixUserAccountObjectType
    _namespace = 'http://cybox.mitre.org/objects#UnixUserAccountObject-2'
    _XSI_NS = "UnixUserAccountObj"
    _XSI_TYPE = "UnixUserAccountObjectType"

    group_id = fields.TypedField("Group_ID", UnsignedInteger)
    user_id = fields.TypedField("User_ID", UnsignedInteger)
    login_shell = fields.TypedField("Login_Shell", String)

    # Override abstract types
    group_list = fields.TypedField('Group_List', UnixGroupList)
    privilege_list = fields.TypedField('Privilege_List', UnixPrivilegeList)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities, fields

import cybox.bindings.cybox_common as common_binding


class InternalStrings(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.InternalStringsType
    _namespace = 'http://cybox.mitre.org/common-2'

    key = fields.TypedField("Key")
    content = fields.TypedField("Content")


class InternationalizationSettings(entities.Entity):
    _binding = common_binding
    _binding_class = common_binding.InternationalizationSettingsType
    _namespace = 'http://cybox.mitre.org/common-2'

    internal_strings = fields.TypedField("Internal_Strings", InternalStrings, multiple=True)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.gui_window_object import GUIWindow
from cybox.test.objects import ObjectTestCase


class TestGUIWindow(ObjectTestCase, unittest.TestCase):
    object_type = "GUIWindowObjectType"
    klass = GUIWindow

    _full_dict = {
        'owner_window': u('owner window'),
        'parent_window': u('parent window'),
        'window_display_name': u('Tilte window'),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.volume_object import FileSystemFlagList, Volume
from cybox.test import EntityTestCase
from cybox.test.objects import ObjectTestCase


class TestFileSystemFlagList(EntityTestCase, unittest.TestCase):
    klass = FileSystemFlagList

    _full_dict = [
        u('FILE_UNICODE_ON_DISK'),
        u('FILE_CASE_SENSITIVE_SEARCH'),
    ]


class TestVolume(ObjectTestCase, unittest.TestCase):
    object_type = "VolumeObjectType"
    klass = Volume

    _full_dict = {
        'is_mounted': True,
        'name': u('sda'),
        'device_path': u('/dev/sda'),
        'file_system_type': u('ext4'),
        'total_allocation_units': 4000787030016,
        'sectors_per_allocation_unit': 976754646,
        'bytes_per_sector': 512,
        'actual_available_allocation_units': 3814697265600,
        'creation_time': '2001-01-01T06:56:50+04:00',
        'file_system_flag_list': TestFileSystemFlagList._full_dict,
        'serial_number': u('WD-WCC4E4LA4965'),
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import fields

import cybox.bindings.unix_file_object as unix_file_binding
from cybox.common import String, UnsignedLong
from cybox.objects.file_object import File, FilePermissions


def _validate_unix_type(instance, value):
    allowed = instance._ALLOWED_VALUES
    if not value:
        return
    elif not allowed:
        return
    elif value in allowed:
        return
    else:
        error = "Value must be one of {allowed}. Received '{value}'"
        error = error.format(**locals())
        raise ValueError(error)


class UnixFilePermissions(FilePermissions):
    _binding = unix_file_binding
    _binding_class = unix_file_binding.UnixFilePermissionsType
    _namespace = "http://cybox.mitre.org/objects#UnixFileObject-2"

    suid = fields.BooleanField("suid")
    sgid = fields.BooleanField("sgid")
    uread = fields.BooleanField("uread")
    uwrite = fields.BooleanField("uwrite")
    uexec = fields.BooleanField("uexec")
    gread = fields.BooleanField("gread")
    gwrite = fields.BooleanField("gwrite")
    gexec = fields.BooleanField("gexec")
    oread = fields.BooleanField("oread")
    owrite = fields.BooleanField("owrite")
    oexec = fields.BooleanField("oexec")


class UnixFile(File):
    _binding = unix_file_binding
    _binding_class = unix_file_binding.UnixFileObjectType
    _namespace = "http://cybox.mitre.org/objects#UnixFileObject-2"
    _XSI_NS = "UnixFileObj"
    _XSI_TYPE = "UnixFileObjectType"

    TYPE_REGULAR_FILE = "regularfile"
    TYPE_DIRECTORY = "directory"
    TYPE_SOCKET = "socket"
    TYPE_SYMBOLIC_LINK = "symboliclink"
    TYPE_BLOCK_SPECIAL_FILE = "blockspecialfile"
    TYPE_CHARACTER_SPECIAL_FILE = "characterspecialfile"

    _ALLOWED_VALUES = (
        TYPE_REGULAR_FILE,
        TYPE_DIRECTORY,
        TYPE_SOCKET,
        TYPE_SYMBOLIC_LINK,
        TYPE_BLOCK_SPECIAL_FILE,
        TYPE_CHARACTER_SPECIAL_FILE
    )

    group_owner = fields.TypedField("Group_Owner", String)
    inode = fields.TypedField("INode", UnsignedLong)
    type_ = fields.TypedField("Type", String, preset_hook=_validate_unix_type)

    # Override abstract types
    permissions = fields.TypedField('Permissions', UnixFilePermissions)

    @property
    def privilege_list(self):
        return self.permissions

    @privilege_list.setter
    def privilege_list(self, value):
        self.permissions = value



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from mixbox.vendor.six import u

from cybox.objects.unix_network_route_entry_object import UnixNetworkRouteEntry
from cybox.test.objects import ObjectTestCase


class TestUnixNetworkRouteEntry(ObjectTestCase, unittest.TestCase):
    object_type = "UnixNetworkRouteEntryObjectType"
    klass = UnixNetworkRouteEntry

    _full_dict = {
        'flags': u('UG'),
        'mss': 0,
        'ref': 345,
        'use': 1642,
        'window': 518,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from cybox.objects.gui_object import GUI
from cybox.test.objects import ObjectTestCase


class TestGUI(ObjectTestCase, unittest.TestCase):
    object_type = "GUIObjectType"
    klass = GUI

    _full_dict = {
        'height': 1024,
        'width': 768,
        'xsi:type': object_type,
    }


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

from mixbox import entities
from mixbox import fields

import cybox.bindings.pdf_file_object as pdf_file_binding
from cybox.objects.file_object import File
from cybox.common import (DateTime, HashList, PositiveInteger, String,
                          NonNegativeInteger, Double, HexBinary, Integer)


def validate_pdf_object_type(instance, value):
    if value is None:
        return
    elif value in PDFIndirectObject.TYPES:
        return
    else:
        err = "Type must be one of %s. Received '%s'." % (PDFIndirectObject.TYPES, value)
        raise ValueError(err)


def validate_pdf_ref_entry_type(instance, value):
    if value is None:
        return
    elif value in PDFXrefEntry.TYPES:
        return
    else:
        err = "Type must be one of %s. Received '%s'." % (PDFXrefEntry.TYPES, value)
        raise ValueError(err)


def validate_id_string(instance, value):
    if value is None:
        return
    elif len(instance.id_string) >= 2:
        err = "ID_String only has a max occurrence of 2."
        raise ValueError(err)
    else:
        return


class PDFKeywordCount(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFKeywordCountType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    non_obfuscated_count = fields.TypedField("Non_Obfuscated_Count", NonNegativeInteger)
    obfuscated_count = fields.TypedField("Obfuscated_Count", NonNegativeInteger)


class PDFKeywordCounts(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFKeywordCountsType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    page_count = fields.TypedField("Page_Count", PDFKeywordCount)
    encrypt_count = fields.TypedField("Encrypt_Count", PDFKeywordCount)
    objstm_count = fields.TypedField("ObjStm_Count", PDFKeywordCount)
    js_count = fields.TypedField("JS_Count", PDFKeywordCount)
    javascript_count = fields.TypedField("JavaScript_Count", PDFKeywordCount)
    aa_count = fields.TypedField("AA_Count", PDFKeywordCount)
    openaction_count = fields.TypedField("OpenAction_Count", PDFKeywordCount)
    asciihexdecode_count = fields.TypedField("ASCIIHexDecode_Count", PDFKeywordCount)
    ascii85decode_count = fields.TypedField("ASCII85Decode_Count", PDFKeywordCount)
    lzwdecode_count = fields.TypedField("LZWDecode_Count", PDFKeywordCount)
    flatedecode_count = fields.TypedField("FlateDecode_Count", PDFKeywordCount)
    runlengthdecode_count = fields.TypedField("RunLengthDecode_Count", PDFKeywordCount)
    jbig2decode_count = fields.TypedField("JBIG2Decode_Count", PDFKeywordCount)
    dctdecode_count = fields.TypedField("DCTDecode_Count", PDFKeywordCount)
    richmedia_count = fields.TypedField("RichMedia_Count", PDFKeywordCount)
    ccittfaxdecode_count = fields.TypedField("CCITTFaxDecode_Count", PDFKeywordCount)
    launch_count = fields.TypedField("Launch_Count", PDFKeywordCount)
    xfa_count = fields.TypedField("XFA_Count", PDFKeywordCount)


class PDFDocumentInformationDictionary(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFDocumentInformationDictionaryType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    title = fields.TypedField("Title", String)
    author = fields.TypedField("Author", String)
    subject = fields.TypedField("Subject", String)
    keywords = fields.TypedField("Keywords", String)
    creator = fields.TypedField("Creator", String)
    producer = fields.TypedField("Producer", String)
    creationdate = fields.TypedField("CreationDate", DateTime)
    moddate = fields.TypedField("ModDate", DateTime)
    trapped = fields.TypedField("Trapped", String)


class PDFFileMetadata(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFFileMetadataType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    encrypted = fields.TypedField("encrypted")
    optimized = fields.TypedField("optimized")
    document_information_dictionary = fields.TypedField("Document_Information_Dictionary", PDFDocumentInformationDictionary)
    number_of_indirect_objects = fields.TypedField("Number_Of_Indirect_Objects", PositiveInteger)
    number_of_trailers = fields.TypedField("Number_Of_Trailers", PositiveInteger)
    number_of_cross_reference_tables = fields.TypedField("Number_Of_Cross_Reference_Tables", PositiveInteger)
    keyword_counts = fields.TypedField("Keyword_Counts", PDFKeywordCounts)


class PDFFileID(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFFileIDType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    id_string = fields.TypedField("ID_String", String, multiple=True, preset_hook=validate_id_string)


class PDFIndirectObjectID(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFIndirectObjectIDType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    object_number = fields.TypedField("Object_Number", PositiveInteger)
    generation_number = fields.TypedField("Generation_Number", NonNegativeInteger)


class PDFDictionary(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFDictionaryType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    # TODO: xs:choice
    object_reference = fields.TypedField("Object_Reference", PDFIndirectObjectID)
    raw_contents = fields.TypedField("Raw_Contents", String)


class PDFStream(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFStreamType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    raw_stream = fields.TypedField("Raw_Stream", String)
    raw_stream_hashes = fields.TypedField("Raw_Stream_Hashes", HashList)
    decoded_stream = fields.TypedField("Decoded_Stream", HexBinary)
    decoded_stream_hashes = fields.TypedField("Decoded_Stream_Hashes", HashList)


class PDFIndirectObjectContents(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFIndirectObjectContentsType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    non_stream_contents = fields.TypedField("Non_Stream_Contents", String)
    stream_contents = fields.TypedField("Stream_Contents", PDFStream)


class PDFIndirectObject(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFIndirectObjectType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    TYPE_BOOLEAN = "Boolean"
    TYPE_INTEGER = "Integer"
    TYPE_STRING = "String"
    TYPE_NAME = "Name"
    TYPE_ARRAY = "Array"
    TYPE_DICTIONARY = "Dictionary"
    TYPE_STREAM = "Stream"
    TYPE_NULL = "Null"
    TYPES = (TYPE_BOOLEAN, TYPE_INTEGER, TYPE_STRING, TYPE_NAME, TYPE_ARRAY,
             TYPE_DICTIONARY, TYPE_STREAM, TYPE_NULL)

    type_ = fields.TypedField("type_", key_name="type", preset_hook=validate_pdf_object_type)
    id_ = fields.TypedField("ID", PDFIndirectObjectID)
    contents = fields.TypedField("Contents", PDFIndirectObjectContents)
    offset = fields.TypedField("Offset", PositiveInteger)
    hashes = fields.TypedField("Hashes", HashList)


class PDFIndirectObjectList(entities.EntityList):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFIndirectObjectListType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    indirect_object = fields.TypedField("Indirect_Object", PDFIndirectObject, multiple=True)


class PDFTrailer(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFTrailerType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    size = fields.TypedField("Size", PositiveInteger)
    prev = fields.TypedField("Prev", PositiveInteger)
    root = fields.TypedField("Root", PDFIndirectObjectID)
    encrypt = fields.TypedField("Encrypt", PDFDictionary)
    info = fields.TypedField("Info", PDFIndirectObjectID)
    id_ = fields.TypedField("ID", PDFFileID)
    last_cross_reference_offset = fields.TypedField("Last_Cross_Reference_Offset", PositiveInteger)
    offset = fields.TypedField("Offset", PositiveInteger)
    hashes = fields.TypedField("Hashes", HashList)


class PDFTrailerList(entities.EntityList):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFTrailerListType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    trailer = fields.TypedField("Trailer", PDFTrailer, multiple=True)


class PDFXrefEntry(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFXrefEntryType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    TYPE_USE = "In-Use"
    TYPE_FREE = "Free"
    TYPES = (TYPE_USE, TYPE_FREE)

    type_ = fields.TypedField("type_", key_name="type", preset_hook=validate_pdf_ref_entry_type)
    # TODO: Byte_Offset and Object_Number xs:choice
    byte_offset = fields.TypedField("Byte_Offset", Integer)
    object_number = fields.TypedField("Object_Number", NonNegativeInteger)
    generation_number = fields.TypedField("Generation_Number", NonNegativeInteger)


class PDFXrefEntryList(entities.EntityList):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFXrefEntryListType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    cross_reference_entry = fields.TypedField("Cross_Reference_Entry", PDFXrefEntry, multiple=True)


class PDFXrefTableSubsection(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFXrefTableSubsectionType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    first_object_number = fields.TypedField("First_Object_Number", NonNegativeInteger)
    number_of_objects = fields.TypedField("Number_Of_Objects", NonNegativeInteger)
    cross_reference_entries = fields.TypedField("Cross_Reference_Entries", PDFXrefEntryList)


class PDFXrefTableSubsectionList(entities.EntityList):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFXrefTableSubsectionListType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    subsection = fields.TypedField("Subsection", PDFXrefTableSubsection, multiple=True)


class PDFXRefTable(entities.Entity):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFXRefTableType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    subsections = fields.TypedField("Subsections", PDFXrefTableSubsectionList)
    offset = fields.TypedField("Offset", PositiveInteger)
    hashes = fields.TypedField("Hashes", HashList)


class PDFXRefTableList(entities.EntityList):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFXRefTableListType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'

    cross_reference_table = fields.TypedField("Cross_Reference_Table", PDFXRefTable, multiple=True)


class PDFFile(File):
    _binding = pdf_file_binding
    _binding_class = pdf_file_binding.PDFFileObjectType
    _namespace = 'http://cybox.mitre.org/objects#PDFFileObject-1'
    _XSI_NS = "PDFFileObj"
    _XSI_TYPE = "PDFFileObjectType"

    metadata = fields.TypedField("Metadata", PDFFileMetadata)
    version = fields.TypedField("Version", Double)
    indirect_objects = fields.TypedField("Indirect_Objects", PDFIndirectObjectList)
    cross_reference_tables = fields.TypedField("Cross_Reference_Tables", PDFXRefTableList)
    trailers = fields.TypedField("Trailers", PDFTrailerList)



# Copyright (c) 2020, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import cybox.bindings.cybox_common as common_binding
from cybox.common import BaseProperty


class CompensationModel(BaseProperty):
    _binding = common_binding
    _binding_class = common_binding.CompensationModelType
    _namespace = 'http://cybox.mitre.org/common-2'

    TERM_FREEWARE = "Freeware"
    TERM_SHAREWARE = "Shareware"
    TERM_COMMERCIAL = "Commercial"
    TERM_ADWARE = "Adware"



# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

import unittest

from cybox.objects.pdf_file_object import PDFFile

from cybox.test.objects import ObjectTestCase


class TestPDFFileInstance(ObjectTestCase, unittest.TestCase):
    object_type = 'PDFFileObjectType'
    klass = PDFFile

    _full_dict = {
        'indirect_objects': [
            {
                'id': {
                    'object_number': 1,
                    'generation_number': 0
                },
                'contents': {
                    'non_stream_contents': '<< /Type /Catalog /Outlines 2 0 R>>'
                }
            },
            {
                'id': {
                    'object_number': 2,
                    'generation_number': 0
                },
                'contents': {
                    'non_stream_contents': '<< /Type Outlines /Count 0>>'
                }
            }
        ],
        'file_name': 'test.pdf',
        'size_in_bytes': 25523,
        'trailers': [{
            'last_cross_reference_offset': 408,
            'root': {
                'object_number': 1,
                'generation_number': 0
            },
            'size': 3
        }],
        'version': 1.4,
        'cross_reference_tables': [{'subsections': [{
            'cross_reference_entries': [
                {
                    'byte_offset': 0,
                    'generation_number': 65535
                },
                {
                    'byte_offset': 9,
                    'generation_number': 0
                },
                {
                    'byte_offset': 74,
                    'generation_number': 0
                }
            ],
            'number_of_objects': 3,
            'first_object_number': 0
        }]}],
        'xsi:type': object_type
    }


class TestPDFFilePattern(ObjectTestCase, unittest.TestCase):
    object_type = 'PDFFileObjectType'
    klass = PDFFile

    _full_dict = {
        'xsi:type': object_type,
        'version': {
            'value': 1.2,
            'condition': 'GreaterThan'
        },
        'metadata': {
            'keyword_counts': {
                'js_count': {
                    'non_obfuscated_count': {
                        'value': 3,
                        'condition': 'GreaterThanOrEqual'
                    }
                }
            }
        }
    }


if __name__ == '__main__':
    unittest.main()
